ActionServiceBase class abstract

Annotations
  • @GrpcServiceName.new('zitadel.action.v2.ActionService')

Constructors

ActionServiceBase()

Properties

$name → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
activatePublicKey(ServiceCall call, ActivatePublicKeyRequest request) → Future<ActivatePublicKeyResponse>
activatePublicKey_Pre(ServiceCall $call, Future<ActivatePublicKeyRequest> $request) → Future<ActivatePublicKeyResponse>
addPublicKey(ServiceCall call, AddPublicKeyRequest request) → Future<AddPublicKeyResponse>
addPublicKey_Pre(ServiceCall $call, Future<AddPublicKeyRequest> $request) → Future<AddPublicKeyResponse>
createTarget(ServiceCall call, CreateTargetRequest request) → Future<CreateTargetResponse>
createTarget_Pre(ServiceCall $call, Future<CreateTargetRequest> $request) → Future<CreateTargetResponse>
deactivatePublicKey(ServiceCall call, DeactivatePublicKeyRequest request) → Future<DeactivatePublicKeyResponse>
deactivatePublicKey_Pre(ServiceCall $call, Future<DeactivatePublicKeyRequest> $request) → Future<DeactivatePublicKeyResponse>
deleteTarget(ServiceCall call, DeleteTargetRequest request) → Future<DeleteTargetResponse>
deleteTarget_Pre(ServiceCall $call, Future<DeleteTargetRequest> $request) → Future<DeleteTargetResponse>
getTarget(ServiceCall call, GetTargetRequest request) → Future<GetTargetResponse>
getTarget_Pre(ServiceCall $call, Future<GetTargetRequest> $request) → Future<GetTargetResponse>
listExecutionFunctions(ServiceCall call, ListExecutionFunctionsRequest request) → Future<ListExecutionFunctionsResponse>
listExecutionFunctions_Pre(ServiceCall $call, Future<ListExecutionFunctionsRequest> $request) → Future<ListExecutionFunctionsResponse>
listExecutionMethods(ServiceCall call, ListExecutionMethodsRequest request) → Future<ListExecutionMethodsResponse>
listExecutionMethods_Pre(ServiceCall $call, Future<ListExecutionMethodsRequest> $request) → Future<ListExecutionMethodsResponse>
listExecutions(ServiceCall call, ListExecutionsRequest request) → Future<ListExecutionsResponse>
listExecutions_Pre(ServiceCall $call, Future<ListExecutionsRequest> $request) → Future<ListExecutionsResponse>
listExecutionServices(ServiceCall call, ListExecutionServicesRequest request) → Future<ListExecutionServicesResponse>
listExecutionServices_Pre(ServiceCall $call, Future<ListExecutionServicesRequest> $request) → Future<ListExecutionServicesResponse>
listPublicKeys(ServiceCall call, ListPublicKeysRequest request) → Future<ListPublicKeysResponse>
listPublicKeys_Pre(ServiceCall $call, Future<ListPublicKeysRequest> $request) → Future<ListPublicKeysResponse>
listTargets(ServiceCall call, ListTargetsRequest request) → Future<ListTargetsResponse>
listTargets_Pre(ServiceCall $call, Future<ListTargetsRequest> $request) → Future<ListTargetsResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removePublicKey(ServiceCall call, RemovePublicKeyRequest request) → Future<RemovePublicKeyResponse>
removePublicKey_Pre(ServiceCall $call, Future<RemovePublicKeyRequest> $request) → Future<RemovePublicKeyResponse>
setExecution(ServiceCall call, SetExecutionRequest request) → Future<SetExecutionResponse>
setExecution_Pre(ServiceCall $call, Future<SetExecutionRequest> $request) → Future<SetExecutionResponse>
toString() → String
A string representation of this object.
inherited
updateTarget(ServiceCall call, UpdateTargetRequest request) → Future<UpdateTargetResponse>
updateTarget_Pre(ServiceCall $call, Future<UpdateTargetRequest> $request) → Future<UpdateTargetResponse>

Operators

operator ==(Object other) → bool
The equality operator.
inherited