deactivatePublicKey method

ResponseFuture<DeactivatePublicKeyResponse> deactivatePublicKey(
  1. DeactivatePublicKeyRequest request, {
  2. CallOptions? options,
})

Deactivate Public Key

Deactivates the public key for payload encryption. The public key will no longer be used to encrypt payloads sent to the target. Be aware that deactivating the active key will leave the target without an active key. Subsequent calls to the target with payload type PAYLOAD_TYPE_JWE will fail until a new key is activated. This endpoint can be used in break glass scenarios to quickly disable a compromised key. Deactivating a key that is already inactive is a no-op.

Required permission:

  • action.target.write

Implementation

$grpc.ResponseFuture<$0.DeactivatePublicKeyResponse> deactivatePublicKey(
  $0.DeactivatePublicKeyRequest request, {
  $grpc.CallOptions? options,
}) {
  return $createUnaryCall(_$deactivatePublicKey, request, options: options);
}