deleteTarget method

ResponseFuture<DeleteTargetResponse> deleteTarget(
  1. DeleteTargetRequest request, {
  2. CallOptions? options,
})

Delete Target

Delete an existing target. This will remove it from any configured execution as well. In case the target is not found, the request will return a successful response as the desired state is already achieved.

Required permission:

  • action.target.delete

Implementation

$grpc.ResponseFuture<$0.DeleteTargetResponse> deleteTarget(
  $0.DeleteTargetRequest request, {
  $grpc.CallOptions? options,
}) {
  return $createUnaryCall(_$deleteTarget, request, options: options);
}