listPublicKeys method
ResponseFuture<ListPublicKeysResponse>
listPublicKeys(
- ListPublicKeysRequest request, {
- CallOptions? options,
List Public Keys
Lists all public keys of a target. The response includes which key is active and the key's expiration dates. This allows you to manage key rotations and ensure that your target always has an active key for payload encryption.
Required permission:
action.target.read
Implementation
$grpc.ResponseFuture<$0.ListPublicKeysResponse> listPublicKeys(
$0.ListPublicKeysRequest request, {
$grpc.CallOptions? options,
}) {
return $createUnaryCall(_$listPublicKeys, request, options: options);
}