setExecution method
ResponseFuture<SetExecutionResponse>
setExecution(
- SetExecutionRequest request, {
- CallOptions? options,
Set Execution
Sets an execution to call a target or include the targets of another execution. Setting an empty list of targets will remove all targets from the execution, making it a noop.
Required permission:
action.execution.write
Implementation
$grpc.ResponseFuture<$0.SetExecutionResponse> setExecution(
$0.SetExecutionRequest request, {
$grpc.CallOptions? options,
}) {
return $createUnaryCall(_$setExecution, request, options: options);
}