keyId property
KeyID is the unique identifier of the public key to activate.
Implementation
@$pb.TagNumber(2)
$core.String get keyId => $_getSZ(1);
Implementation
@$pb.TagNumber(2)
set keyId($core.String value) => $_setString(1, value);
KeyID is the unique identifier of the public key to activate.
@$pb.TagNumber(2)
$core.String get keyId => $_getSZ(1);
@$pb.TagNumber(2)
set keyId($core.String value) => $_setString(1, value);