expirationDate property

  1. @TagNumber.new(3)
Timestamp get expirationDate

Optional expiration date of the public key. After the expiration date, the key will be automatically deactivated and no longer used for payload encryption. Be sure to activate a new key before the current active key expires to avoid interruptions. If not set, the key will not expire.

Implementation

@$pb.TagNumber(3)
$3.Timestamp get expirationDate => $_getN(2);
  1. @TagNumber.new(3)
set expirationDate (Timestamp value)

Implementation

@$pb.TagNumber(3)
set expirationDate($3.Timestamp value) => $_setField(3, value);