keyId property
The KeyID is the unique identifier of the newly added public key.
The ID is also used a kid in the JWT header for payload encryption.
This allows the target to identify the correct key to use for decryption.
Implementation
@$pb.TagNumber(1)
$core.String get keyId => $_getSZ(0);
Implementation
@$pb.TagNumber(1)
set keyId($core.String value) => $_setString(0, value);