CreateTargetRequest class
- Available extensions
Constructors
- CreateTargetRequest({String? name, RESTWebhook? restWebhook, RESTCall? restCall, RESTAsync? restAsync, Duration? timeout, String? endpoint, PayloadType? payloadType})
-
factory
-
CreateTargetRequest.fromBuffer(List<
int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY]) -
factory
- CreateTargetRequest.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
-
factory
Properties
- endpoint ↔ String
-
The URL of the endpoint to call.
getter/setter pair
- hashCode → int
-
Calculates a hash code based on the contents of the protobuf.
no setterinherited
- info_ → BuilderInfo
-
no setter
- isFrozen → bool
-
Returns
trueif this message is marked read-only. Otherwisefalse.no setterinherited - name ↔ String
-
getter/setter pair
- payloadType ↔ PayloadType
-
Payload type defines how the payload is formatted and secured.
The default is
PAYLOAD_TYPE_JSON, which sends the payload as JSON in the body of the request. For integrity and authenticity a signature is included in the headerX-ZITADEL-Signature. You can also choose to send the payload as a JWT (PAYLOAD_TYPE_JWT), which sends the payload as a signed JWT in the body of the request. This allows the receiver to verify the authenticity and integrity of the payload using the signing key. If you need encryption as well, you can choosePAYLOAD_TYPE_JWE, which sends the payload as an encrypted JWT in the body of the request. You can provide your own public key for encryption.getter/setter pair - restAsync ↔ RESTAsync
-
The HTTP call to this target will be a POST request.
The call is sent asynchronously and ZITADEL does not wait for the response.
The response of the target is ignored, no status or body is checked.
This is typically used for executions of type "events".
getter/setter pair
- restCall ↔ RESTCall
-
The HTTP call to this target will be a POST request.
The response of the target will be checked for the status code and the body.
In case of an error status code (non 2xx) and interrupt_on_error is set to true,
the execution will be aborted and no further targets will be called.
In case of a successful status code (2xx) the body will be parsed and mapped.
This allows to modify the payload of request and response executions.
getter/setter pair
- restWebhook ↔ RESTWebhook
-
The HTTP call to this target will be a POST request.
The response of the target will only be checked for the status code.
The returned body will be ignored.
In case of an error status code (non 2xx) and interrupt_on_error is set to true,
the execution will be aborted and no further targets will be called.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeout ↔ Duration
-
Timeout defines the duration until ZITADEL cancels the execution.
If the target doesn't respond before this timeout expires, then the connection is closed and the action fails.
Depending on the target type and possible setting on
interrupt_on_errorfollowing targets will not be called. In case of arest_asynctarget only this specific target will fail, without any influence on other targets of the same execution. The maximum timeout is 270 seconds or 4.5 minutes.getter/setter pair - unknownFields → UnknownFieldSet
-
no setterinherited
Methods
-
addExtension(
Extension extension, Object? value) → void -
Adds an extension field value to a repeated field.
inherited
-
check(
) → void -
Throws a StateError if the message has required fields without a value.
inherited
-
clear(
) → void -
Clears all data that was set in this message.
inherited
-
clearEndpoint(
) → void -
clearExtension(
Extension extension) → void -
Clears an extension field and also removes the extension.
inherited
-
clearField(
int tagNumber) → void -
Clears the contents of a given field.
inherited
-
clearName(
) → void -
clearPayloadType(
) → void -
clearRestAsync(
) → void -
clearRestCall(
) → void -
clearRestWebhook(
) → void -
clearTargetType(
) → void -
clearTimeout(
) → void -
clone(
) → CreateTargetRequest - Creates a deep copy of the fields in this message.
-
copyWith(
void updates(CreateTargetRequest)) → CreateTargetRequest -
Apply
updatesto a copy of this message. -
createEmptyInstance(
) → CreateTargetRequest - Creates an empty instance of the same message type as this.
-
deepCopy(
) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Returns a writable deep copy of this message. -
ensureRestAsync(
) → RESTAsync -
ensureRestCall(
) → RESTCall -
ensureRestWebhook(
) → RESTWebhook -
ensureTimeout(
) → Duration -
extensionsAreInitialized(
) → bool -
inherited
-
freeze(
) → GeneratedMessage -
Make this message read-only.
inherited
-
getDefaultForField(
int tagNumber) → dynamic -
Returns the default value for the given field.
inherited
-
getExtension(
Extension extension) → dynamic -
Returns the value of
extension.inherited -
getField(
int tagNumber) → dynamic -
Returns the value of the field associated with
tagNumber, or the default value if it is not set.inherited -
getFieldOrNull(
int tagNumber) → dynamic -
Returns the value of a field, ignoring any defaults.
inherited
-
getTagNumber(
String fieldName) → int? -
inherited
-
hasEndpoint(
) → bool -
hasExtension(
Extension extension) → bool -
Returns
trueif a value ofextensionis present.inherited -
hasField(
int tagNumber) → bool -
Whether this message has a field associated with
tagNumber.inherited -
hasName(
) → bool -
hasPayloadType(
) → bool -
hasRequiredFields(
) → bool -
Whether the message has required fields.
inherited
-
hasRestAsync(
) → bool -
hasRestCall(
) → bool -
hasRestWebhook(
) → bool -
hasTimeout(
) → bool -
isInitialized(
) → bool -
Whether all required fields in the message and embedded messages are set.
inherited
-
mergeFromBuffer(
List< int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges serialized protocol buffer data into this message.
inherited
-
mergeFromCodedBufferReader(
CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Same as
mergeFromBuffer, but takes aCodedBufferReaderinput.inherited -
mergeFromJson(
String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from
data, a JSON object, encoded as described byGeneratedMessage.writeToJson.inherited -
mergeFromJsonMap(
Map< String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from a JSON object represented as a Dart map.
inherited
-
mergeFromMessage(
GeneratedMessage other) → void -
Merges the contents of the
otherinto this message.inherited -
mergeFromProto3Json(
Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void -
Merges field values from
json, a JSON object using proto3 encoding.inherited -
mergeUnknownFields(
UnknownFieldSet unknownFieldSet) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates(T)) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Applyupdatesto a copy of this message. -
setExtension(
Extension extension, Object value) → void -
Sets the value of a non-repeated extension field to
value.inherited -
setField(
int tagNumber, Object value) → void -
Sets the value of a field by its
tagNumber.inherited -
toBuilder(
) → GeneratedMessage -
Creates a writable, shallow copy of this message.
inherited
-
toDebugString(
) → String -
Returns a String representation of this message.
inherited
-
toProto3Json(
{TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object? -
Returns an Object representing Proto3 JSON serialization of
this.inherited -
toString(
) → String -
Returns a String representation of this message.
inherited
-
whichTargetType(
) → CreateTargetRequest_TargetType -
writeToBuffer(
) → Uint8List -
Serialize the message as the protobuf binary format.
inherited
-
writeToCodedBufferWriter(
CodedBufferWriter output) → void -
Same as
writeToBuffer, but serializes to the givenCodedBufferWriter.inherited -
writeToJson(
) → String -
Returns a JSON string that encodes this message.
inherited
-
writeToJsonMap(
) → Map< String, dynamic> -
Returns the JSON encoding of this message as a Dart Map.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited