restAsync property

  1. @TagNumber.new(4)
RESTAsync get restAsync

The HTTP call to this target will be a POST request. The call is sent asynchronously and ZITADEL does not wait for the response. The response of the target is ignored, no status or body is checked. This is typically used for executions of type "events".

Implementation

@$pb.TagNumber(4)
$1.RESTAsync get restAsync => $_getN(3);
  1. @TagNumber.new(4)
set restAsync (RESTAsync value)

Implementation

@$pb.TagNumber(4)
set restAsync($1.RESTAsync value) => $_setField(4, value);