restCall property
The HTTP call to this target will be a POST request. The response of the target will be checked for the status code and the body. In case of an error status code (non 2xx) and interrupt_on_error is set to true, the execution will be aborted and no further targets will be called. In case of a successful status code (2xx) the body will be parsed and mapped. This allows to modify the payload of request and response executions.
Implementation
@$pb.TagNumber(3)
$1.RESTCall get restCall => $_getN(2);
Implementation
@$pb.TagNumber(3)
set restCall($1.RESTCall value) => $_setField(3, value);