restWebhook property

  1. @TagNumber.new(3)
RESTWebhook get restWebhook

The HTTP call to this target will be a POST request. The response of the target will only be checked for the status code. The returned body will be ignored. In case of an error status code (non 2xx) and interrupt_on_error is set to true, the execution will be aborted and no further targets will be called.

Implementation

@$pb.TagNumber(3)
$1.RESTWebhook get restWebhook => $_getN(2);
  1. @TagNumber.new(3)
set restWebhook (RESTWebhook value)

Implementation

@$pb.TagNumber(3)
set restWebhook($1.RESTWebhook value) => $_setField(3, value);