ImportDataRequest class

Available extensions

Constructors

ImportDataRequest({ImportDataOrg? dataOrgs, ImportDataOrg? dataOrgsv1, ImportDataRequest_LocalInput? dataOrgsLocal, ImportDataRequest_LocalInput? dataOrgsv1Local, ImportDataRequest_S3Input? dataOrgsS3, ImportDataRequest_S3Input? dataOrgsv1S3, ImportDataRequest_GCSInput? dataOrgsGcs, ImportDataRequest_GCSInput? dataOrgsv1Gcs, String? timeout})
factory
ImportDataRequest.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
ImportDataRequest.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

dataOrgs ↔ ImportDataOrg
getter/setter pair
dataOrgsGcs ↔ ImportDataRequest_GCSInput
getter/setter pair
dataOrgsLocal ↔ ImportDataRequest_LocalInput
getter/setter pair
dataOrgsS3 ↔ ImportDataRequest_S3Input
getter/setter pair
dataOrgsv1 ↔ ImportDataOrg
getter/setter pair
dataOrgsv1Gcs ↔ ImportDataRequest_GCSInput
getter/setter pair
dataOrgsv1Local ↔ ImportDataRequest_LocalInput
getter/setter pair
dataOrgsv1S3 ↔ ImportDataRequest_S3Input
getter/setter pair
hashCode → int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setter
isFrozen → bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeout ↔ String
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearData() → void
clearDataOrgs() → void
clearDataOrgsGcs() → void
clearDataOrgsLocal() → void
clearDataOrgsS3() → void
clearDataOrgsv1() → void
clearDataOrgsv1Gcs() → void
clearDataOrgsv1Local() → void
clearDataOrgsv1S3() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearTimeout() → void
clone() → ImportDataRequest
Creates a deep copy of the fields in this message.
copyWith(void updates(ImportDataRequest)) → ImportDataRequest
Apply updates to a copy of this message.
createEmptyInstance() → ImportDataRequest
Creates an empty instance of the same message type as this.
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
ensureDataOrgs() → ImportDataOrg
ensureDataOrgsGcs() → ImportDataRequest_GCSInput
ensureDataOrgsLocal() → ImportDataRequest_LocalInput
ensureDataOrgsS3() → ImportDataRequest_S3Input
ensureDataOrgsv1() → ImportDataOrg
ensureDataOrgsv1Gcs() → ImportDataRequest_GCSInput
ensureDataOrgsv1Local() → ImportDataRequest_LocalInput
ensureDataOrgsv1S3() → ImportDataRequest_S3Input
extensionsAreInitialized() → bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) → int?
inherited
hasDataOrgs() → bool
hasDataOrgsGcs() → bool
hasDataOrgsLocal() → bool
hasDataOrgsS3() → bool
hasDataOrgsv1() → bool
hasDataOrgsv1Gcs() → bool
hasDataOrgsv1Local() → bool
hasDataOrgsv1S3() → bool
hasExtension(Extension extension) → bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) → bool
Whether this message has a field associated with tagNumber.
inherited
hasRequiredFields() → bool
Whether the message has required fields.
inherited
hasTimeout() → bool
isInitialized() → bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() → String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() → String
Returns a String representation of this message.
inherited
whichData() → ImportDataRequest_Data
writeToBuffer() → Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() → String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() → Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited