scopes property

  1. @TagNumber.new(2)
PbList<String> get scopes

scopes is a list of scopes which should be requested from the authorization service. To authorize a token to use the smtp functionality, the server requires a specific scope. These scopes can be found in the documentation of the provider.

Implementation

@$pb.TagNumber(2)
$pb.PbList<$core.String> get scopes => $_getList(1);