CreateOIDCApplicationRequest class

Available extensions

Constructors

CreateOIDCApplicationRequest({Iterable<String>? redirectUris, Iterable<OIDCResponseType>? responseTypes, Iterable<OIDCGrantType>? grantTypes, OIDCAppType? appType, OIDCAuthMethodType? authMethodType, Iterable<String>? postLogoutRedirectUris, OIDCVersion? version, bool? devMode, OIDCTokenType? accessTokenType, bool? accessTokenRoleAssertion, bool? idTokenRoleAssertion, bool? idTokenUserinfoAssertion, Duration? clockSkew, Iterable<String>? additionalOrigins, bool? skipNativeAppSuccessPage, String? backChannelLogoutUri, LoginVersion? loginVersion})
factory
CreateOIDCApplicationRequest.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
CreateOIDCApplicationRequest.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

accessTokenRoleAssertion ↔ bool
getter/setter pair
accessTokenType ↔ OIDCTokenType
getter/setter pair
additionalOrigins → PbList<String>
no setter
appType ↔ OIDCAppType
getter/setter pair
authMethodType ↔ OIDCAuthMethodType
getter/setter pair
backChannelLogoutUri ↔ String
getter/setter pair
clockSkew ↔ Duration
getter/setter pair
devMode ↔ bool
getter/setter pair
grantTypes → PbList<OIDCGrantType>
no setter
hashCode → int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
idTokenRoleAssertion ↔ bool
getter/setter pair
idTokenUserinfoAssertion ↔ bool
getter/setter pair
info_ → BuilderInfo
no setter
isFrozen → bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
loginVersion ↔ LoginVersion
getter/setter pair
postLogoutRedirectUris → PbList<String>
Zitadel will redirect to this link after a successful logout
no setter
redirectUris → PbList<String>
Callback URI of the authorization request where the code or tokens will be sent to
no setter
responseTypes → PbList<OIDCResponseType>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skipNativeAppSuccessPage ↔ bool
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited
version ↔ OIDCVersion
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearAccessTokenRoleAssertion() → void
clearAccessTokenType() → void
clearAppType() → void
clearAuthMethodType() → void
clearBackChannelLogoutUri() → void
clearClockSkew() → void
clearDevMode() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearIdTokenRoleAssertion() → void
clearIdTokenUserinfoAssertion() → void
clearLoginVersion() → void
clearSkipNativeAppSuccessPage() → void
clearVersion() → void
clone() → CreateOIDCApplicationRequest
Creates a deep copy of the fields in this message.
copyWith(void updates(CreateOIDCApplicationRequest)) → CreateOIDCApplicationRequest
Apply updates to a copy of this message.
createEmptyInstance() → CreateOIDCApplicationRequest
Creates an empty instance of the same message type as this.
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
ensureClockSkew() → Duration
ensureLoginVersion() → LoginVersion
extensionsAreInitialized() → bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) → int?
inherited
hasAccessTokenRoleAssertion() → bool
hasAccessTokenType() → bool
hasAppType() → bool
hasAuthMethodType() → bool
hasBackChannelLogoutUri() → bool
hasClockSkew() → bool
hasDevMode() → bool
hasExtension(Extension extension) → bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) → bool
Whether this message has a field associated with tagNumber.
inherited
hasIdTokenRoleAssertion() → bool
hasIdTokenUserinfoAssertion() → bool
hasLoginVersion() → bool
hasRequiredFields() → bool
Whether the message has required fields.
inherited
hasSkipNativeAppSuccessPage() → bool
hasVersion() → bool
isInitialized() → bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() → String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() → String
Returns a String representation of this message.
inherited
writeToBuffer() → Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() → String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() → Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited