postLogoutRedirectUris property
Zitadel will redirect to this link after a successful logout
Implementation
@$pb.TagNumber(6)
$pb.PbList<$core.String> get postLogoutRedirectUris => $_getList(5);
Zitadel will redirect to this link after a successful logout
@$pb.TagNumber(6)
$pb.PbList<$core.String> get postLogoutRedirectUris => $_getList(5);