redirectUris property
Callback URI of the authorization request where the code or tokens will be sent to
Implementation
@$pb.TagNumber(1)
$pb.PbList<$core.String> get redirectUris => $_getList(0);
Callback URI of the authorization request where the code or tokens will be sent to
@$pb.TagNumber(1)
$pb.PbList<$core.String> get redirectUris => $_getList(0);