deletionDate property
The timestamp of the application deletion. In case the application was already deleted, the previous deletion date is returned. This can be used to check if the application was actually deleted.
Implementation
@$pb.TagNumber(1)
$1.Timestamp get deletionDate => $_getN(0);
Implementation
@$pb.TagNumber(1)
set deletionDate($1.Timestamp value) => $_setField(1, value);