listMyUserGrants method
ResponseFuture<ListMyUserGrantsResponse>
listMyUserGrants(
- ListMyUserGrantsRequest request, {
- CallOptions? options,
List My Authorizations / Role Assignments
Deprecated: List authorizations and pass the user ID filter with your users ID to search for your authorizations on granted and owned projects.
Returns a list of the authorizations/role assignments the authenticated user has. Role assignments consist of an organization, a project and 1-n roles.
Note: Authorization in this context refers to role assignments, not to OAuth authorization.
Implementation
$grpc.ResponseFuture<$0.ListMyUserGrantsResponse> listMyUserGrants(
$0.ListMyUserGrantsRequest request, {
$grpc.CallOptions? options,
}) {
return $createUnaryCall(_$listMyUserGrants, request, options: options);
}