loginHint property
Login hint can be set by the application with a user identifier such as an email or phone number.
Implementation
@$pb.TagNumber(8)
$core.String get loginHint => $_getSZ(7);
Implementation
@$pb.TagNumber(8)
set loginHint($core.String value) => $_setString(7, value);