maxAge property

  1. @TagNumber.new(9)
Duration get maxAge

Specifies the allowable elapsed time in seconds since the last time the End-User was actively authenticated. If the elapsed time is greater than this value, or the field is present with 0 duration, the user must be re-authenticated.

Implementation

@$pb.TagNumber(9)
$1.Duration get maxAge => $_getN(8);
  1. @TagNumber.new(9)
set maxAge (Duration value)

Implementation

@$pb.TagNumber(9)
set maxAge($1.Duration value) => $_setField(9, value);