scope property
The scopes by the application that the user must consent to.
Implementation
@$pb.TagNumber(4)
$pb.PbList<$core.String> get scope => $_getList(3);
The scopes by the application that the user must consent to.
@$pb.TagNumber(4)
$pb.PbList<$core.String> get scope => $_getList(3);