changeDate property
ChangeDate is the timestamp when the authorization was last updated. In case the authorization was not updated, this field is equal to the creation date.
Implementation
@$pb.TagNumber(3)
$0.Timestamp get changeDate => $_getN(2);
Implementation
@$pb.TagNumber(3)
set changeDate($0.Timestamp value) => $_setField(3, value);