organization property

  1. @TagNumber.new(5)
Organization get organization

The organization the user was granted the authorization for. This does not have to correspond with the project or user's organization. But does represent the organization to which the authorization belongs and the user was given permissions for.

Implementation

@$pb.TagNumber(5)
Organization get organization => $_getN(4);
  1. @TagNumber.new(5)
set organization (Organization value)

Implementation

@$pb.TagNumber(5)
set organization(Organization value) => $_setField(5, value);