roles property
Roles contains the roles the user was granted for the project.
Implementation
@$pb.TagNumber(8)
$pb.PbList<Role> get roles => $_getList(7);
Roles contains the roles the user was granted for the project.
@$pb.TagNumber(8)
$pb.PbList<Role> get roles => $_getList(7);