AuthorizationServiceBase class abstract

Annotations
  • @GrpcServiceName.new('zitadel.authorization.v2.AuthorizationService')

Constructors

AuthorizationServiceBase()

Properties

$name → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
activateAuthorization(ServiceCall call, ActivateAuthorizationRequest request) → Future<ActivateAuthorizationResponse>
activateAuthorization_Pre(ServiceCall $call, Future<ActivateAuthorizationRequest> $request) → Future<ActivateAuthorizationResponse>
createAuthorization(ServiceCall call, CreateAuthorizationRequest request) → Future<CreateAuthorizationResponse>
createAuthorization_Pre(ServiceCall $call, Future<CreateAuthorizationRequest> $request) → Future<CreateAuthorizationResponse>
deactivateAuthorization(ServiceCall call, DeactivateAuthorizationRequest request) → Future<DeactivateAuthorizationResponse>
deactivateAuthorization_Pre(ServiceCall $call, Future<DeactivateAuthorizationRequest> $request) → Future<DeactivateAuthorizationResponse>
deleteAuthorization(ServiceCall call, DeleteAuthorizationRequest request) → Future<DeleteAuthorizationResponse>
deleteAuthorization_Pre(ServiceCall $call, Future<DeleteAuthorizationRequest> $request) → Future<DeleteAuthorizationResponse>
listAuthorizations(ServiceCall call, ListAuthorizationsRequest request) → Future<ListAuthorizationsResponse>
listAuthorizations_Pre(ServiceCall $call, Future<ListAuthorizationsRequest> $request) → Future<ListAuthorizationsResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
updateAuthorization(ServiceCall call, UpdateAuthorizationRequest request) → Future<UpdateAuthorizationResponse>
updateAuthorization_Pre(ServiceCall $call, Future<UpdateAuthorizationRequest> $request) → Future<UpdateAuthorizationResponse>

Operators

operator ==(Object other) → bool
The equality operator.
inherited