activateAuthorization method
ResponseFuture<ActivateAuthorizationResponse>
activateAuthorization(
- ActivateAuthorizationRequest request, {
- CallOptions? options,
Activate Authorization
Deprecated: please move to the corresponding endpoint under authorization service v2. This endpoint will be removed with the next major version of ZITADEL.
ActivateAuthorization activates an existing but inactive authorization.
Note: Authorization in this context refers to role assignments, not to OAuth authorization.
In case the authorization is already active, the request will return a successful response as the desired state is already achieved. You can check the change date in the response to verify if the authorization was activated by the request.
Required permissions:
- "user.grant.write"
Implementation
$grpc.ResponseFuture<$0.ActivateAuthorizationResponse> activateAuthorization(
$0.ActivateAuthorizationRequest request, {
$grpc.CallOptions? options,
}) {
return $createUnaryCall(_$activateAuthorization, request, options: options);
}