updateAuthorization method
ResponseFuture<UpdateAuthorizationResponse>
updateAuthorization(
- UpdateAuthorizationRequest request, {
- CallOptions? options,
Update Role Assignments
Note: Authorization in this context refers to role assignments, not to OAuth authorization.
UpdateAuthorization updates the authorization.
Note that any role keys previously granted to the user and not present in the request will be revoked.
Required permissions:
- "user.grant.write"
Implementation
$grpc.ResponseFuture<$0.UpdateAuthorizationResponse> updateAuthorization(
$0.UpdateAuthorizationRequest request, {
$grpc.CallOptions? options,
}) {
return $createUnaryCall(_$updateAuthorization, request, options: options);
}