urlTemplate property
Optionally set a url_template, which will be used in the mail sent by Zitadel to guide the user to your verification page. If no template is set, the default Zitadel url will be used.
The following placeholders can be used: Code, UserID, LoginName, DisplayName, PreferredLanguage, SessionID
Implementation
@$pb.TagNumber(1)
$core.String get urlTemplate => $_getSZ(0);
Implementation
@$pb.TagNumber(1)
set urlTemplate($core.String value) => $_setString(0, value);