returnCode property

  1. @TagNumber.new(1)
bool get returnCode

Request the code to be returned instead of sending an SMS. This is useful for testing or in case you want to send the code yourself.

Implementation

@$pb.TagNumber(1)
$core.bool get returnCode => $_getBF(0);
  1. @TagNumber.new(1)
set returnCode (bool value)

Implementation

@$pb.TagNumber(1)
set returnCode($core.bool value) => $_setBool(0, value);