domain property

  1. @TagNumber.new(1)
String get domain

The domain on which the session was created. Will be used in the WebAuthN challenge. It must be either the exact domain or a top-level domain of the origin of the request. For example if the request is coming from "login.example.com", the domain can be "login.example.com" or "example.com", but not "other.com" or "sub.login.example.com". See also: https://www.w3.org/TR/webauthn/#relying-party-identifier

Implementation

@$pb.TagNumber(1)
$core.String get domain => $_getSZ(0);
  1. @TagNumber.new(1)
set domain (String value)

Implementation

@$pb.TagNumber(1)
set domain($core.String value) => $_setString(0, value);