userVerificationRequirement property
User verification that is required during validation.
When set to USER_VERIFICATION_REQUIREMENT_REQUIRED the behaviour is for passkey authentication.
Other values will mean U2F.
See also: https://www.w3.org/TR/webauthn/#enum-userVerificationRequirement
If either the value is set to USER_VERIFICATION_REQUIREMENT_REQUIRED or the user verification
is passed as part of the authentication ceremony, the user_verified flag will be set in the resulting webauthn factor.
Implementation
@$pb.TagNumber(2)
UserVerificationRequirement get userVerificationRequirement => $_getN(1);
Implementation
@$pb.TagNumber(2)
set userVerificationRequirement(UserVerificationRequirement value) =>
$_setField(2, value);