Edition class

The full set of known editions.

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
This enum's name, as specified in the .proto file.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
This enum's integer value, as specified in the .proto file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

valueOf(int value) → Edition?

Constants

EDITION_1_TEST_ONLY → const Edition
Placeholder editions for testing feature resolution. These should not be used or relied on outside of tests.
EDITION_2_TEST_ONLY → const Edition
EDITION_2023 → const Edition
Editions that have been released. The specific values are arbitrary and should not be depended on, but they will always be time-ordered for easy comparison.
EDITION_2024 → const Edition
EDITION_99997_TEST_ONLY → const Edition
EDITION_99998_TEST_ONLY → const Edition
EDITION_99999_TEST_ONLY → const Edition
EDITION_LEGACY → const Edition
A placeholder edition for specifying default behaviors before a feature was first introduced. This is effectively an "infinite past".
EDITION_MAX → const Edition
Placeholder for specifying unbounded edition support. This should only ever be used by plugins that can expect to never require any changes to support a new edition.
EDITION_PROTO2 → const Edition
Legacy syntax "editions". These pre-date editions, but behave much like distinct editions. These can't be used to specify the edition of proto files, but feature definitions must supply proto2/proto3 defaults for backwards compatibility.
EDITION_PROTO3 → const Edition
EDITION_UNKNOWN → const Edition
A placeholder for an unknown edition value.
values → const List<Edition>