SymbolVisibility class

Describes the 'visibility' of a symbol with respect to the proto import system. Symbols can only be imported when the visibility rules do not prevent it (ex: local symbols cannot be imported). Visibility modifiers can only set on message and enum as they are the only types available to be referenced from other files.

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
This enum's name, as specified in the .proto file.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
This enum's integer value, as specified in the .proto file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

valueOf(int value) → SymbolVisibility?