required property
Require that all users must use the new login UI. If enabled, all users will be redirected to the login V2 regardless of the application's preference.
Implementation
@$pb.TagNumber(1)
$core.bool get required => $_getBF(0);
Implementation
@$pb.TagNumber(1)
set required($core.bool value) => $_setBool(0, value);