roles property
Roles are the roles that should be granted to the user for the specified resource. Note that roles are currently specific to the resource type. This means that if you want to grant a user the administrator role for an organization and a project, you need to create two administrator roles.
Implementation
@$pb.TagNumber(3)
$pb.PbList<$core.String> get roles => $_getList(2);