InternalPermissionServiceClient class

InternalPermissionService provides methods to manage permissions for resource and their management in Zitadel itself also known as "administrators".

If you want to manage permissions and roles within your project or application, please use the AuthorizationsService.

Annotations
  • @GrpcServiceName.new('zitadel.internal_permission.v2.InternalPermissionService')

Constructors

InternalPermissionServiceClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R>
inherited
createAdministrator(CreateAdministratorRequest request, {CallOptions? options}) → ResponseFuture<CreateAdministratorResponse>
Create Administrator
deleteAdministrator(DeleteAdministratorRequest request, {CallOptions? options}) → ResponseFuture<DeleteAdministratorResponse>
Delete Administrator
listAdministrators(ListAdministratorsRequest request, {CallOptions? options}) → ResponseFuture<ListAdministratorsResponse>
List Administrators
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateAdministrator(UpdateAdministratorRequest request, {CallOptions? options}) → ResponseFuture<UpdateAdministratorResponse>
Update Administrator

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultHost → const String
The hostname for this service.
oauthScopes → const List<String>
OAuth scopes needed for the client.