maxPasswordAttempts property

  1. @TagNumber.new(1)
Int64 get maxPasswordAttempts

The amount of failed password attempts before the account gets locked. Attempts are reset as soon as the password is entered correctly or the password is reset. If set to 0 the account will never be locked.

Implementation

@$pb.TagNumber(1)
$fixnum.Int64 get maxPasswordAttempts => $_getI64(0);
  1. @TagNumber.new(1)
set maxPasswordAttempts (Int64 value)

Implementation

@$pb.TagNumber(1)
set maxPasswordAttempts($fixnum.Int64 value) => $_setInt64(0, value);