allowDomainDiscovery property

  1. @TagNumber.new(16)
bool get allowDomainDiscovery

Allow discovery of the organization and its authentication option by domain. If set to true, the suffix (@domain.com) of an unknown username input on the login screen will be matched against the Organization Domains and will redirect to the registration of that organization on success. The registration can either be locally (requires allow_register to be true) or through an external identity provider. In case only one identity provider is configured for the organization, the user will be redirected directly to the identity provider.

Implementation

@$pb.TagNumber(16)
$core.bool get allowDomainDiscovery => $_getBF(15);
  1. @TagNumber.new(16)
set allowDomainDiscovery (bool value)

Implementation

@$pb.TagNumber(16)
set allowDomainDiscovery($core.bool value) => $_setBool(15, value);