allowLocalAuthentication property

  1. @TagNumber.new(20)
bool get allowLocalAuthentication

If enabled, users can log in locally with their username and passkeys or password. Disabling this option will require users to log in with an external identity provider. Be sure to allow at least one external identity provider if this option is disabled.

Implementation

@$pb.TagNumber(20)
$core.bool get allowLocalAuthentication => $_getBF(19);
  1. @TagNumber.new(20)
set allowLocalAuthentication (bool value)

Implementation

@$pb.TagNumber(20)
set allowLocalAuthentication($core.bool value) => $_setBool(19, value);