allowRegister property
If enabled, users can register a local account by themself. This option does not effect external identity providers. Each identity provider can be configured to allow or disallow registration.
Implementation
@$pb.TagNumber(2)
$core.bool get allowRegister => $_getBF(1);
Implementation
@$pb.TagNumber(2)
set allowRegister($core.bool value) => $_setBool(1, value);