allowUsernamePassword property

  1. @Deprecated('This field is deprecated.')
  2. @TagNumber.new(1)
bool get allowUsernamePassword

If enabled, users can log in locally with their username and passkeys or password. Disabling this option will require users to log in with an external identity provider. Be sure to allow at least one external identity provider if this option is disabled. Deprecated: check allow_local_authentication instead.

Implementation

@$core.Deprecated('This field is deprecated.')
@$pb.TagNumber(1)
$core.bool get allowUsernamePassword => $_getBF(0);
  1. @Deprecated('This field is deprecated.')
  2. @TagNumber.new(1)
set allowUsernamePassword (bool value)

Implementation

@$core.Deprecated('This field is deprecated.')
@$pb.TagNumber(1)
set allowUsernamePassword($core.bool value) => $_setBool(0, value);