disableLoginWithPhone property

  1. @TagNumber.new(18)
bool get disableLoginWithPhone

By default, users can login with their verified phone number additionally to their login name. Setting this to true disables the phone number login. Note: If the phone number is set as the login name, this setting has no effect.

Implementation

@$pb.TagNumber(18)
$core.bool get disableLoginWithPhone => $_getBF(17);
  1. @TagNumber.new(18)
set disableLoginWithPhone (bool value)

Implementation

@$pb.TagNumber(18)
set disableLoginWithPhone($core.bool value) => $_setBool(17, value);