forceMfa property

  1. @TagNumber.new(4)
bool get forceMfa

If enabled, users will be forced to use a multi-factor to log in. This also applies to federated logins through an external identity provider. Users will be required to set up a second factor if they have not done so already.

Implementation

@$pb.TagNumber(4)
$core.bool get forceMfa => $_getBF(3);
  1. @TagNumber.new(4)
set forceMfa (bool value)

Implementation

@$pb.TagNumber(4)
set forceMfa($core.bool value) => $_setBool(3, value);