bulkRemoveUserGrant method

ResponseFuture<BulkRemoveUserGrantResponse> bulkRemoveUserGrant(
  1. BulkRemoveUserGrantRequest request, {
  2. CallOptions? options,
})

Bulk Remove User Grants

Deprecated: Delete authorizations one after the other to remove access for multiple users on multiple owned or granted projects.

Remove a list of user grants (role assignments). The users will not be able to use the granted project anymore. Also, the roles will not be included in the tokens when requested.

Note: User grant refers to role assignments.

Implementation

$grpc.ResponseFuture<$0.BulkRemoveUserGrantResponse> bulkRemoveUserGrant(
  $0.BulkRemoveUserGrantRequest request, {
  $grpc.CallOptions? options,
}) {
  return $createUnaryCall(_$bulkRemoveUserGrant, request, options: options);
}