importHumanUser method

ResponseFuture<ImportHumanUserResponse> importHumanUser(
  1. ImportHumanUserRequest request, {
  2. CallOptions? options,
})

Create/Import User (Human)

Deprecated: use user service v2 UpdateHumanUser instead.

Create/import a new user. The newly created user will get an initialization email if either the email address is not marked as verified or no password is set. If a password is set the user will not be requested to set a new one on the first login.

Implementation

$grpc.ResponseFuture<$0.ImportHumanUserResponse> importHumanUser(
  $0.ImportHumanUserRequest request, {
  $grpc.CallOptions? options,
}) {
  return $createUnaryCall(_$importHumanUser, request, options: options);
}