desc property

  1. @TagNumber.new(3)
bool get desc

If desc is true, the result is sorted by in descending order. Beware that if desc is true or the sorting column is not the creation date, the pagination results might be inconsistent.

Implementation

@$pb.TagNumber(3)
$core.bool get desc => $_getBF(2);
  1. @TagNumber.new(3)
set desc (bool value)

Implementation

@$pb.TagNumber(3)
set desc($core.bool value) => $_setBool(2, value);