callbackUrl property

  1. @TagNumber.new(2)
String get callbackUrl

The callback URL where the user should be redirected using an HTTP "302 FOUND" status. This contains details for the application to obtain the tokens on success, or error details on failure. Note that this field must be treated as credentials, as the contained code can be used to obtain tokens on behalf of the user."

Implementation

@$pb.TagNumber(2)
$core.String get callbackUrl => $_getSZ(1);
  1. @TagNumber.new(2)
set callbackUrl (String value)

Implementation

@$pb.TagNumber(2)
set callbackUrl($core.String value) => $_setString(1, value);