OIDCServiceBase class abstract

Annotations
  • @GrpcServiceName.new('zitadel.oidc.v2beta.OIDCService')

Constructors

OIDCServiceBase()

Properties

$name → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
createCallback(ServiceCall call, CreateCallbackRequest request) → Future<CreateCallbackResponse>
createCallback_Pre(ServiceCall $call, Future<CreateCallbackRequest> $request) → Future<CreateCallbackResponse>
getAuthRequest(ServiceCall call, GetAuthRequestRequest request) → Future<GetAuthRequestResponse>
getAuthRequest_Pre(ServiceCall $call, Future<GetAuthRequestRequest> $request) → Future<GetAuthRequestResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited