OIDCServiceClient class
- Annotations
-
- @GrpcServiceName.new('zitadel.oidc.v2.OIDCService')
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options})
→ ClientCall<Q, R>
-
inherited
-
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options})
→ ResponseStream<R>
-
inherited
-
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options})
→ ResponseFuture<R>
-
inherited
-
authorizeOrDenyDeviceAuthorization(AuthorizeOrDenyDeviceAuthorizationRequest request, {CallOptions? options})
→ ResponseFuture<AuthorizeOrDenyDeviceAuthorizationResponse>
-
Authorize or Deny Device Authorization
-
createCallback(CreateCallbackRequest request, {CallOptions? options})
→ ResponseFuture<CreateCallbackResponse>
-
Create Callback
-
getAuthRequest(GetAuthRequestRequest request, {CallOptions? options})
→ ResponseFuture<GetAuthRequestResponse>
-
Get Auth Request
-
getDeviceAuthorizationRequest(GetDeviceAuthorizationRequestRequest request, {CallOptions? options})
→ ResponseFuture<GetDeviceAuthorizationRequestResponse>
-
Get Device Authorization Request
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited