getDeviceAuthorizationRequest method
ResponseFuture<GetDeviceAuthorizationRequestResponse>
getDeviceAuthorizationRequest(
- GetDeviceAuthorizationRequestRequest request, {
- CallOptions? options,
Get Device Authorization Request
Get the device authorization based on the provided "user code". This will return the device authorization request, which contains the device authorization id that is required to authorize the request once the user signed in or to deny it.
Required permissions:
session.read
Implementation
$grpc.ResponseFuture<$0.GetDeviceAuthorizationRequestResponse>
getDeviceAuthorizationRequest(
$0.GetDeviceAuthorizationRequestRequest request, {
$grpc.CallOptions? options,
}) {
return $createUnaryCall(_$getDeviceAuthorizationRequest, request,
options: options);
}