DomainValidationType class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's
nameor thevalueif names are not represented.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → DomainValidationType?
Constants
- DOMAIN_VALIDATION_TYPE_DNS → const DomainValidationType
- DNS validation requires you to create a specific TXT record in your domain's DNS settings. This record is checked by us to verify that you own the domain.
- DOMAIN_VALIDATION_TYPE_HTTP → const DomainValidationType
- HTTP validation requires you to host a specific file on your domain. This file is checked by us to verify that you own the domain.
- DOMAIN_VALIDATION_TYPE_UNSPECIFIED → const DomainValidationType
-
values
→ const List<
DomainValidationType>