domain property
Domain is the full qualified domain name to be added to the organization. Note that the domain has to be unique across the instance. Depending on the settings, you might have to verify the domain before it can be used.
Implementation
@$pb.TagNumber(2)
$core.String get domain => $_getSZ(1);
Implementation
@$pb.TagNumber(2)
set domain($core.String value) => $_setString(1, value);