admins property
Specify users to be assigned as organization admins. If no users are specified here, the organization will be created without any admin users. The organization can still be managed by any instance administrator. If no roles are specified for a user, they will be assigned the role ORG_OWNER.
Implementation
@$pb.TagNumber(2)
$pb.PbList<AddOrganizationRequest_Admin> get admins => $_getList(1);