domain property

  1. @TagNumber.new(2)
String get domain

Domain is the full qualified domain name to be deleted from the organization. Note that if the domain is used as suffix for user logins, those users will not be able to log in anymore. They have to use another domain instead. Also if the domain was used for domain discovery, users will not be able to find the organization by the domain anymore.

Implementation

@$pb.TagNumber(2)
$core.String get domain => $_getSZ(1);
  1. @TagNumber.new(2)
set domain (String value)

Implementation

@$pb.TagNumber(2)
set domain($core.String value) => $_setString(1, value);