keys property
Keys are the organization metadata entries to be deleted by their key.
Implementation
@$pb.TagNumber(2)
$pb.PbList<$core.String> get keys => $_getList(1);
Keys are the organization metadata entries to be deleted by their key.
@$pb.TagNumber(2)
$pb.PbList<$core.String> get keys => $_getList(1);