organizationId property
OrganizationID is the unique identifier of the organization for which the domain validation is to be generated.
Implementation
@$pb.TagNumber(1)
$core.String get organizationId => $_getSZ(0);
Implementation
@$pb.TagNumber(1)
set organizationId($core.String value) => $_setString(0, value);