type property
Type is the domain validation type to be generated. Depending on the type, you will have to add a DNS record or a file to your webserver. Make sure that the challenge is reachable via the chosen method. The validation has to be done within one hour, otherwise the token will expire and you will have to generate a new one. After you have added the record or the file, you can verify the domain via the VerifyOrganizationDomain endpoint. You can check the status of the domain via the ListOrganizationDomains endpoint. The domain will be marked as verified after a successful verification.
Implementation
@$pb.TagNumber(3)
$5.DomainValidationType get type => $_getN(2);
Implementation
@$pb.TagNumber(3)
set type($5.DomainValidationType value) => $_setField(3, value);