sortingColumn property
SortingColumn is the field the result is sorted by. Beware that if you change this, your result pagination might be inconsistent.
Implementation
@$pb.TagNumber(4)
$4.DomainFieldName get sortingColumn => $_getN(3);
Implementation
@$pb.TagNumber(4)
set sortingColumn($4.DomainFieldName value) => $_setField(4, value);