result property
The Result is a list of organizations matching the query.
Implementation
@$pb.TagNumber(3)
$pb.PbList<$5.Organization> get result => $_getList(2);
The Result is a list of organizations matching the query.
@$pb.TagNumber(3)
$pb.PbList<$5.Organization> get result => $_getList(2);