value property
Value in the metadata key/value pair. On updates, an empty value will delete the metadata entry.
Implementation
@$pb.TagNumber(2)
$core.List<$core.int> get value => $_getN(1);
Value in the metadata key/value pair. On updates, an empty value will delete the metadata entry.
@$pb.TagNumber(2)
$core.List<$core.int> get value => $_getN(1);