activateOrganization method

ResponseFuture<ActivateOrganizationResponse> activateOrganization(
  1. ActivateOrganizationRequest request, {
  2. CallOptions? options,
})

Activate Organization

Deprecated: please move to the corresponding endpoint under organization service v2. This endpoint will be removed with the next major version of ZITADEL.

Set the state of my organization to active. The state of the organization has to be deactivated to perform the request. Users of this organization will be able to log in again.

Required permission:

  • org.write

Implementation

$grpc.ResponseFuture<$0.ActivateOrganizationResponse> activateOrganization(
  $0.ActivateOrganizationRequest request, {
  $grpc.CallOptions? options,
}) {
  return $createUnaryCall(_$activateOrganization, request, options: options);
}