deactivateOrganization method

ResponseFuture<DeactivateOrganizationResponse> deactivateOrganization(
  1. DeactivateOrganizationRequest request, {
  2. CallOptions? options,
})

Deactivate Organization

Deprecated: please move to the corresponding endpoint under organization service v2. This endpoint will be removed with the next major version of ZITADEL.

Sets the state of my organization to deactivated. Users of this organization will not be able to log in.

Required permission:

  • org.write

Implementation

$grpc.ResponseFuture<$0.DeactivateOrganizationResponse>
    deactivateOrganization(
  $0.DeactivateOrganizationRequest request, {
  $grpc.CallOptions? options,
}) {
  return $createUnaryCall(_$deactivateOrganization, request,
      options: options);
}