deleteOrganization method

ResponseFuture<DeleteOrganizationResponse> deleteOrganization(
  1. DeleteOrganizationRequest request, {
  2. CallOptions? options,
})

Delete Organization

Deprecated: please move to the corresponding endpoint under organization service v2. This endpoint will be removed with the next major version of ZITADEL.

Deletes the organization and all its resources (Users, Projects, Grants to and from the org). Users of this organization will not be able to log in.

Required permission:

  • org.delete

Implementation

$grpc.ResponseFuture<$0.DeleteOrganizationResponse> deleteOrganization(
  $0.DeleteOrganizationRequest request, {
  $grpc.CallOptions? options,
}) {
  return $createUnaryCall(_$deleteOrganization, request, options: options);
}