listOrganizations method
ResponseFuture<ListOrganizationsResponse>
listOrganizations(
- ListOrganizationsRequest request, {
- CallOptions? options,
List Organizations
Deprecated: please move to the corresponding endpoint under organization service v2. This endpoint will be removed with the next major version of ZITADEL.
Returns a list of organizations that match the requesting filters. All filters are applied with an AND condition.
Required permission:
org.read
Deprecated: Use ListOrganizations instead to list organizations.
Implementation
$grpc.ResponseFuture<$0.ListOrganizationsResponse> listOrganizations(
$0.ListOrganizationsRequest request, {
$grpc.CallOptions? options,
}) {
return $createUnaryCall(_$listOrganizations, request, options: options);
}