setOrganizationMetadata method

ResponseFuture<SetOrganizationMetadataResponse> setOrganizationMetadata(
  1. SetOrganizationMetadataRequest request, {
  2. CallOptions? options,
})

Set Organization Metadata

Deprecated: please move to the corresponding endpoint under organization service v2. This endpoint will be removed with the next major version of ZITADEL.

Adds or updates a metadata value for the requested key. Make sure the value is base64 encoded.

Required permission:

  • org.write

Implementation

$grpc.ResponseFuture<$0.SetOrganizationMetadataResponse>
    setOrganizationMetadata(
  $0.SetOrganizationMetadataRequest request, {
  $grpc.CallOptions? options,
}) {
  return $createUnaryCall(_$setOrganizationMetadata, request,
      options: options);
}