updateOrganization method

ResponseFuture<UpdateOrganizationResponse> updateOrganization(
  1. UpdateOrganizationRequest request, {
  2. CallOptions? options,
})

Update Organization

Deprecated: please move to the corresponding endpoint under organization service v2. This endpoint will be removed with the next major version of ZITADEL.

Change the name of the organization.

Required permission:

  • org.write

Implementation

$grpc.ResponseFuture<$0.UpdateOrganizationResponse> updateOrganization(
  $0.UpdateOrganizationRequest request, {
  $grpc.CallOptions? options,
}) {
  return $createUnaryCall(_$updateOrganization, request, options: options);
}