verifyOrganizationDomain method
ResponseFuture<VerifyOrganizationDomainResponse>
verifyOrganizationDomain(
- VerifyOrganizationDomainRequest request, {
- CallOptions? options,
Verify Organization Domain
Deprecated: please move to the corresponding endpoint under organization service v2. This endpoint will be removed with the next major version of ZITADEL.
Make sure you have added the required verification to your domain, depending on the method you have chosen (HTTP or DNS challenge). Zitadel will check it and set the domain as verified if it was successful. A verify domain has to be unique.
Required permission:
org.write
Implementation
$grpc.ResponseFuture<$0.VerifyOrganizationDomainResponse>
verifyOrganizationDomain(
$0.VerifyOrganizationDomainRequest request, {
$grpc.CallOptions? options,
}) {
return $createUnaryCall(_$verifyOrganizationDomain, request,
options: options);
}