name property
Name is the new name for the organization to be set. Note that since the name is used to generate the organization's default domain, changing the name will also change the domain. Additionally, if the domain is used as suffix for user logins, their login names will also change accordingly. It will not affect any Organization Domains added to the organization.
Implementation
@$pb.TagNumber(2)
$core.String get name => $_getSZ(1);
Implementation
@$pb.TagNumber(2)
set name($core.String value) => $_setString(1, value);