LabelPolicy class

Available extensions

Constructors

LabelPolicy({ObjectDetails? details, String? primaryColor, bool? isDefault, bool? hideLoginNameSuffix, String? warnColor, String? backgroundColor, String? fontColor, String? primaryColorDark, String? backgroundColorDark, String? warnColorDark, String? fontColorDark, bool? disableWatermark, String? logoUrl, String? iconUrl, String? logoUrlDark, String? iconUrlDark, String? fontUrl, ThemeMode? themeMode})
factory
LabelPolicy.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
LabelPolicy.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

backgroundColor ↔ String
hex value for background color
getter/setter pair
backgroundColorDark ↔ String
hex value for background color dark theme
getter/setter pair
details ↔ ObjectDetails
getter/setter pair
disableWatermark ↔ bool
getter/setter pair
fontColor ↔ String
hex value for font color
getter/setter pair
fontColorDark ↔ String
hex value for font color dark theme
getter/setter pair
fontUrl ↔ String
getter/setter pair
hashCode → int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
hideLoginNameSuffix ↔ bool
hides the org suffix on the login form if the scope "urn:zitadel:iam:org:domain:primary:{domainname}" is set
getter/setter pair
iconUrl ↔ String
getter/setter pair
iconUrlDark ↔ String
getter/setter pair
info_ → BuilderInfo
no setter
isDefault ↔ bool
defines if the organization's admin changed the policy
getter/setter pair
isFrozen → bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
logoUrl ↔ String
getter/setter pair
logoUrlDark ↔ String
getter/setter pair
primaryColor ↔ String
hex value for primary color
getter/setter pair
primaryColorDark ↔ String
hex value for primary color dark theme
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
themeMode ↔ ThemeMode
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited
warnColor ↔ String
hex value for secondary color
getter/setter pair
warnColorDark ↔ String
hex value for warning color dark theme
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearBackgroundColor() → void
clearBackgroundColorDark() → void
clearDetails() → void
clearDisableWatermark() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearFontColor() → void
clearFontColorDark() → void
clearFontUrl() → void
clearHideLoginNameSuffix() → void
clearIconUrl() → void
clearIconUrlDark() → void
clearIsDefault() → void
clearLogoUrl() → void
clearLogoUrlDark() → void
clearPrimaryColor() → void
clearPrimaryColorDark() → void
clearThemeMode() → void
clearWarnColor() → void
clearWarnColorDark() → void
clone() → LabelPolicy
Creates a deep copy of the fields in this message.
copyWith(void updates(LabelPolicy)) → LabelPolicy
Apply updates to a copy of this message.
createEmptyInstance() → LabelPolicy
Creates an empty instance of the same message type as this.
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
ensureDetails() → ObjectDetails
extensionsAreInitialized() → bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) → int?
inherited
hasBackgroundColor() → bool
hasBackgroundColorDark() → bool
hasDetails() → bool
hasDisableWatermark() → bool
hasExtension(Extension extension) → bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) → bool
Whether this message has a field associated with tagNumber.
inherited
hasFontColor() → bool
hasFontColorDark() → bool
hasFontUrl() → bool
hasHideLoginNameSuffix() → bool
hasIconUrl() → bool
hasIconUrlDark() → bool
hasIsDefault() → bool
hasLogoUrl() → bool
hasLogoUrlDark() → bool
hasPrimaryColor() → bool
hasPrimaryColorDark() → bool
hasRequiredFields() → bool
Whether the message has required fields.
inherited
hasThemeMode() → bool
hasWarnColor() → bool
hasWarnColorDark() → bool
isInitialized() → bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() → String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() → String
Returns a String representation of this message.
inherited
writeToBuffer() → Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() → String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() → Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

create() → LabelPolicy
getDefault() → LabelPolicy