LoginPolicy class

Available extensions

Constructors

LoginPolicy({ObjectDetails? details, bool? allowUsernamePassword, bool? allowRegister, bool? allowExternalIdp, bool? forceMfa, PasswordlessType? passwordlessType, bool? isDefault, bool? hidePasswordReset, bool? ignoreUnknownUsernames, String? defaultRedirectUri, Duration? passwordCheckLifetime, Duration? externalLoginCheckLifetime, Duration? mfaInitSkipLifetime, Duration? secondFactorCheckLifetime, Duration? multiFactorCheckLifetime, Iterable<SecondFactorType>? secondFactors, Iterable<MultiFactorType>? multiFactors, Iterable<IDPLoginPolicyLink>? idps, bool? allowDomainDiscovery, bool? disableLoginWithEmail, bool? disableLoginWithPhone, bool? forceMfaLocalOnly})
factory
LoginPolicy.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
LoginPolicy.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

allowDomainDiscovery ↔ bool
If set to true, the suffix (@domain.com) of an unknown username input on the login screen will be matched against the org domains and will redirect to the registration of that organization on success.
getter/setter pair
allowExternalIdp ↔ bool
getter/setter pair
allowRegister ↔ bool
getter/setter pair
allowUsernamePassword ↔ bool
getter/setter pair
defaultRedirectUri ↔ String
getter/setter pair
details ↔ ObjectDetails
getter/setter pair
disableLoginWithEmail ↔ bool
getter/setter pair
disableLoginWithPhone ↔ bool
getter/setter pair
externalLoginCheckLifetime ↔ Duration
getter/setter pair
forceMfa ↔ bool
getter/setter pair
forceMfaLocalOnly ↔ bool
getter/setter pair
hashCode → int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
hidePasswordReset ↔ bool
getter/setter pair
idps → PbList<IDPLoginPolicyLink>
no setter
ignoreUnknownUsernames ↔ bool
getter/setter pair
info_ → BuilderInfo
no setter
isDefault ↔ bool
getter/setter pair
isFrozen → bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
mfaInitSkipLifetime ↔ Duration
getter/setter pair
multiFactorCheckLifetime ↔ Duration
getter/setter pair
multiFactors → PbList<MultiFactorType>
no setter
passwordCheckLifetime ↔ Duration
getter/setter pair
passwordlessType ↔ PasswordlessType
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondFactorCheckLifetime ↔ Duration
getter/setter pair
secondFactors → PbList<SecondFactorType>
no setter
unknownFields → UnknownFieldSet
no setterinherited

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearAllowDomainDiscovery() → void
clearAllowExternalIdp() → void
clearAllowRegister() → void
clearAllowUsernamePassword() → void
clearDefaultRedirectUri() → void
clearDetails() → void
clearDisableLoginWithEmail() → void
clearDisableLoginWithPhone() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearExternalLoginCheckLifetime() → void
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearForceMfa() → void
clearForceMfaLocalOnly() → void
clearHidePasswordReset() → void
clearIgnoreUnknownUsernames() → void
clearIsDefault() → void
clearMfaInitSkipLifetime() → void
clearMultiFactorCheckLifetime() → void
clearPasswordCheckLifetime() → void
clearPasswordlessType() → void
clearSecondFactorCheckLifetime() → void
clone() → LoginPolicy
Creates a deep copy of the fields in this message.
copyWith(void updates(LoginPolicy)) → LoginPolicy
Apply updates to a copy of this message.
createEmptyInstance() → LoginPolicy
Creates an empty instance of the same message type as this.
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
ensureDetails() → ObjectDetails
ensureExternalLoginCheckLifetime() → Duration
ensureMfaInitSkipLifetime() → Duration
ensureMultiFactorCheckLifetime() → Duration
ensurePasswordCheckLifetime() → Duration
ensureSecondFactorCheckLifetime() → Duration
extensionsAreInitialized() → bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) → int?
inherited
hasAllowDomainDiscovery() → bool
hasAllowExternalIdp() → bool
hasAllowRegister() → bool
hasAllowUsernamePassword() → bool
hasDefaultRedirectUri() → bool
hasDetails() → bool
hasDisableLoginWithEmail() → bool
hasDisableLoginWithPhone() → bool
hasExtension(Extension extension) → bool
Returns true if a value of extension is present.
inherited
hasExternalLoginCheckLifetime() → bool
hasField(int tagNumber) → bool
Whether this message has a field associated with tagNumber.
inherited
hasForceMfa() → bool
hasForceMfaLocalOnly() → bool
hasHidePasswordReset() → bool
hasIgnoreUnknownUsernames() → bool
hasIsDefault() → bool
hasMfaInitSkipLifetime() → bool
hasMultiFactorCheckLifetime() → bool
hasPasswordCheckLifetime() → bool
hasPasswordlessType() → bool
hasRequiredFields() → bool
Whether the message has required fields.
inherited
hasSecondFactorCheckLifetime() → bool
isInitialized() → bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() → String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() → String
Returns a String representation of this message.
inherited
writeToBuffer() → Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() → String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() → Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

create() → LoginPolicy
getDefault() → LoginPolicy