maxAgeDays property

  1. @TagNumber.new(2)
Int64 get maxAgeDays

Amount of days after which a password will expire. The user will be forced to change the password on the following authentication.

Implementation

@$pb.TagNumber(2)
$fixnum.Int64 get maxAgeDays => $_getI64(1);
  1. @TagNumber.new(2)
set maxAgeDays (Int64 value)

Implementation

@$pb.TagNumber(2)
set maxAgeDays($fixnum.Int64 value) => $_setInt64(1, value);