roleKeys property
RoleKeys is a list of roles to be granted to the organization for self management. The roles are identified by their keys.
Implementation
@$pb.TagNumber(3)
$pb.PbList<$core.String> get roleKeys => $_getList(2);
RoleKeys is a list of roles to be granted to the organization for self management. The roles are identified by their keys.
@$pb.TagNumber(3)
$pb.PbList<$core.String> get roleKeys => $_getList(2);