CreateProjectRequest class
- Available extensions
Constructors
- CreateProjectRequest({String? organizationId, String? projectId, String? name, bool? projectRoleAssertion, bool? authorizationRequired, bool? projectAccessRequired, PrivateLabelingSetting? privateLabelingSetting})
-
factory
-
CreateProjectRequest.fromBuffer(List<
int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY]) -
factory
- CreateProjectRequest.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
-
factory
Properties
-
AuthorizationRequired is a boolean flag that can be enabled to check if a user has
an authorization to use this project assigned when login into an application of this project.
getter/setter pair
- hashCode → int
-
Calculates a hash code based on the contents of the protobuf.
no setterinherited
- info_ → BuilderInfo
-
no setter
- isFrozen → bool
-
Returns
trueif this message is marked read-only. Otherwisefalse.no setterinherited - name ↔ String
-
Name of the project. This might be presented to users, e.g. in sign-in flows.
getter/setter pair
- organizationId ↔ String
-
OrganizationID is the unique identifier of the organization the project belongs to.
getter/setter pair
- privateLabelingSetting ↔ PrivateLabelingSetting
-
PrivateLabelingSetting is a setting that defines which private labeling/branding should
trigger when getting to a login of this project.
getter/setter pair
- projectAccessRequired ↔ bool
-
ProjectAccessRequired is a boolean flag that can be enabled to check if the organization
of the user, that is trying to log in,
has access to this project (either owns the project or is granted).
getter/setter pair
- projectId ↔ String
-
ProjectID is the unique identifier of the new project. This field is optional.
If omitted, the system will generate a unique ID for you. This is the
recommended way. The generated ID will be returned in the response.
getter/setter pair
- projectRoleAssertion ↔ bool
-
ProjectRoleAssertion is a setting that can be enabled to have role information
included in the user info endpoint.
It is also dependent on your application settings to include it in tokens and other types.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- unknownFields → UnknownFieldSet
-
no setterinherited
Methods
-
addExtension(
Extension extension, Object? value) → void -
Adds an extension field value to a repeated field.
inherited
-
check(
) → void -
Throws a StateError if the message has required fields without a value.
inherited
-
clear(
) → void -
Clears all data that was set in this message.
inherited
-
clearAuthorizationRequired(
) → void -
clearExtension(
Extension extension) → void -
Clears an extension field and also removes the extension.
inherited
-
clearField(
int tagNumber) → void -
Clears the contents of a given field.
inherited
-
clearName(
) → void -
clearOrganizationId(
) → void -
clearPrivateLabelingSetting(
) → void -
clearProjectAccessRequired(
) → void -
clearProjectId(
) → void -
clearProjectRoleAssertion(
) → void -
clone(
) → CreateProjectRequest - Creates a deep copy of the fields in this message.
-
copyWith(
void updates(CreateProjectRequest)) → CreateProjectRequest -
Apply
updatesto a copy of this message. -
createEmptyInstance(
) → CreateProjectRequest - Creates an empty instance of the same message type as this.
-
deepCopy(
) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Returns a writable deep copy of this message. -
extensionsAreInitialized(
) → bool -
inherited
-
freeze(
) → GeneratedMessage -
Make this message read-only.
inherited
-
getDefaultForField(
int tagNumber) → dynamic -
Returns the default value for the given field.
inherited
-
getExtension(
Extension extension) → dynamic -
Returns the value of
extension.inherited -
getField(
int tagNumber) → dynamic -
Returns the value of the field associated with
tagNumber, or the default value if it is not set.inherited -
getFieldOrNull(
int tagNumber) → dynamic -
Returns the value of a field, ignoring any defaults.
inherited
-
getTagNumber(
String fieldName) → int? -
inherited
-
hasAuthorizationRequired(
) → bool -
hasExtension(
Extension extension) → bool -
Returns
trueif a value ofextensionis present.inherited -
hasField(
int tagNumber) → bool -
Whether this message has a field associated with
tagNumber.inherited -
hasName(
) → bool -
hasOrganizationId(
) → bool -
hasPrivateLabelingSetting(
) → bool -
hasProjectAccessRequired(
) → bool -
hasProjectId(
) → bool -
hasProjectRoleAssertion(
) → bool -
hasRequiredFields(
) → bool -
Whether the message has required fields.
inherited
-
isInitialized(
) → bool -
Whether all required fields in the message and embedded messages are set.
inherited
-
mergeFromBuffer(
List< int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges serialized protocol buffer data into this message.
inherited
-
mergeFromCodedBufferReader(
CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Same as
mergeFromBuffer, but takes aCodedBufferReaderinput.inherited -
mergeFromJson(
String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from
data, a JSON object, encoded as described byGeneratedMessage.writeToJson.inherited -
mergeFromJsonMap(
Map< String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from a JSON object represented as a Dart map.
inherited
-
mergeFromMessage(
GeneratedMessage other) → void -
Merges the contents of the
otherinto this message.inherited -
mergeFromProto3Json(
Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void -
Merges field values from
json, a JSON object using proto3 encoding.inherited -
mergeUnknownFields(
UnknownFieldSet unknownFieldSet) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates(T)) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Applyupdatesto a copy of this message. -
setExtension(
Extension extension, Object value) → void -
Sets the value of a non-repeated extension field to
value.inherited -
setField(
int tagNumber, Object value) → void -
Sets the value of a field by its
tagNumber.inherited -
toBuilder(
) → GeneratedMessage -
Creates a writable, shallow copy of this message.
inherited
-
toDebugString(
) → String -
Returns a String representation of this message.
inherited
-
toProto3Json(
{TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object? -
Returns an Object representing Proto3 JSON serialization of
this.inherited -
toString(
) → String -
Returns a String representation of this message.
inherited
-
writeToBuffer(
) → Uint8List -
Serialize the message as the protobuf binary format.
inherited
-
writeToCodedBufferWriter(
CodedBufferWriter output) → void -
Same as
writeToBuffer, but serializes to the givenCodedBufferWriter.inherited -
writeToJson(
) → String -
Returns a JSON string that encodes this message.
inherited
-
writeToJsonMap(
) → Map< String, dynamic> -
Returns the JSON encoding of this message as a Dart Map.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited