projectAccessRequired property

  1. @TagNumber.new(6)
bool get projectAccessRequired

ProjectAccessRequired is a boolean flag that can be enabled to check if the organization of the user, that is trying to log in, has access to this project (either owns the project or is granted).

Implementation

@$pb.TagNumber(6)
$core.bool get projectAccessRequired => $_getBF(5);
  1. @TagNumber.new(6)
set projectAccessRequired (bool value)

Implementation

@$pb.TagNumber(6)
set projectAccessRequired($core.bool value) => $_setBool(5, value);