projectId property

  1. @TagNumber.new(2)
String get projectId

ProjectID is the unique identifier of the new project. This field is optional. If omitted, the system will generate a unique ID for you. This is the recommended way. The generated ID will be returned in the response.

Implementation

@$pb.TagNumber(2)
$core.String get projectId => $_getSZ(1);
  1. @TagNumber.new(2)
set projectId (String value)

Implementation

@$pb.TagNumber(2)
set projectId($core.String value) => $_setString(1, value);