projectRoleAssertion property
ProjectRoleAssertion is a setting that can be enabled to have role information included in the user info endpoint. It is also dependent on your application settings to include it in tokens and other types.
Implementation
@$pb.TagNumber(4)
$core.bool get projectRoleAssertion => $_getBF(3);
Implementation
@$pb.TagNumber(4)
set projectRoleAssertion($core.bool value) => $_setBool(3, value);