project property
Project is the project that matches the project ID used in the request.
Implementation
@$pb.TagNumber(1)
$2.Project get project => $_getN(0);
Implementation
@$pb.TagNumber(1)
set project($2.Project value) => $_setField(1, value);
Project is the project that matches the project ID used in the request.
@$pb.TagNumber(1)
$2.Project get project => $_getN(0);
@$pb.TagNumber(1)
set project($2.Project value) => $_setField(1, value);