projectGrants property
ProjectGrants is a list of project grants matching the query.
Implementation
@$pb.TagNumber(2)
$pb.PbList<$2.ProjectGrant> get projectGrants => $_getList(1);
ProjectGrants is a list of project grants matching the query.
@$pb.TagNumber(2)
$pb.PbList<$2.ProjectGrant> get projectGrants => $_getList(1);