projects property
Projects is a list of projects matching the query.
Implementation
@$pb.TagNumber(2)
$pb.PbList<$2.Project> get projects => $_getList(1);
Projects is a list of projects matching the query.
@$pb.TagNumber(2)
$pb.PbList<$2.Project> get projects => $_getList(1);