createProject method

ResponseFuture<CreateProjectResponse> createProject(
  1. CreateProjectRequest request, {
  2. CallOptions? options,
})

Create Project

Create a new project. A project is a vessel to group applications, roles and authorizations. Every project belongs to exactly one organization, but can be granted to other organizations for self-management of their authorizations.

Required permission:

  • project.create

Implementation

$grpc.ResponseFuture<$0.CreateProjectResponse> createProject(
  $0.CreateProjectRequest request, {
  $grpc.CallOptions? options,
}) {
  return $createUnaryCall(_$createProject, request, options: options);
}