roleKey property

  1. @TagNumber.new(2)
String get roleKey

RoleKey is the key of the role to be removed. All dependencies of this role will be removed as well, including project grants and user grants. If the role is not found, the request will return a successful response as the desired state is already achieved.

Implementation

@$pb.TagNumber(2)
$core.String get roleKey => $_getSZ(1);
  1. @TagNumber.new(2)
set roleKey (String value)

Implementation

@$pb.TagNumber(2)
set roleKey($core.String value) => $_setString(1, value);