roleKeys property
RoleKeys is a list of roles to be granted to the organization for self management. The roles are identified by their keys. Any roles not included in this list will be removed from the project grant. If you want to add a role, make sure to include all other existing roles as well. If any previous role is removed, all user grants for this project grant with this role will be removed as well.
Implementation
@$pb.TagNumber(3)
$pb.PbList<$core.String> get roleKeys => $_getList(2);