authorizationRequired property

  1. @TagNumber.new(4)
bool get authorizationRequired

AuthorizationRequired is a boolean flag that can be enabled to check if a user has a role of this project assigned when logging into an application of this project. If omitted, the setting will remain unchanged.

Implementation

@$pb.TagNumber(4)
$core.bool get authorizationRequired => $_getBF(3);
  1. @TagNumber.new(4)
set authorizationRequired (bool value)

Implementation

@$pb.TagNumber(4)
set authorizationRequired($core.bool value) => $_setBool(3, value);