projectAccessRequired property
ProjectAccessRequired is a boolean flag that can be enabled to check if the organization of the user has a grant to this project. If omitted, the setting will remain unchanged.
Implementation
@$pb.TagNumber(5)
$core.bool get projectAccessRequired => $_getBF(4);
Implementation
@$pb.TagNumber(5)
set projectAccessRequired($core.bool value) => $_setBool(4, value);