group property

  1. @TagNumber.new(4)
String get group

Group allows grouping roles for display purposes. Zitadel will not handle it in any way. It can be used to group roles in a UI to allow easier management for administrators. If omitted, the group will remain unchanged. This attribute is not to be confused with groups as a collection of users.

Implementation

@$pb.TagNumber(4)
$core.String get group => $_getSZ(3);
  1. @TagNumber.new(4)
set group (String value)

Implementation

@$pb.TagNumber(4)
set group($core.String value) => $_setString(3, value);