roles property
Roles are the roles that were granted to the user for the specified resource.
Implementation
@$pb.TagNumber(8)
$pb.PbList<$core.String> get roles => $_getList(7);
Roles are the roles that were granted to the user for the specified resource.
@$pb.TagNumber(8)
$pb.PbList<$core.String> get roles => $_getList(7);