grantedOrganizationId property
GrantedOrganizationID is the ID of the organization the project is granted to. In case the project is not granted, this field is unset.
Implementation
@$pb.TagNumber(12)
$core.String get grantedOrganizationId => $_getSZ(10);
Implementation
@$pb.TagNumber(12)
set grantedOrganizationId($core.String value) => $_setString(10, value);