grantedOrganizationName property
GrantedOrganizationName is the name of the organization the project is granted to. In case the project is not granted, this field is unset.
Implementation
@$pb.TagNumber(13)
$core.String get grantedOrganizationName => $_getSZ(11);
Implementation
@$pb.TagNumber(13)
set grantedOrganizationName($core.String value) => $_setString(11, value);