projectRoleAssertion property
ProjectRoleAssertion is a boolean flag that describes if the roles of the user should be added to the token.
Implementation
@$pb.TagNumber(7)
$core.bool get projectRoleAssertion => $_getBF(6);
Implementation
@$pb.TagNumber(7)
set projectRoleAssertion($core.bool value) => $_setBool(6, value);