PublicKeyFieldName class

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
This enum's name, as specified in the .proto file.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
This enum's integer value, as specified in the .proto file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

valueOf(int value) PublicKeyFieldName?

Constants

PUBLIC_KEY_FIELD_NAME_CHANGE_DATE → const PublicKeyFieldName
Sort by change date.
PUBLIC_KEY_FIELD_NAME_CREATION_DATE → const PublicKeyFieldName
Sort by creation date.
PUBLIC_KEY_FIELD_NAME_EXPIRATION_DATE → const PublicKeyFieldName
Sort by expiration date.
PUBLIC_KEY_FIELD_NAME_UNSPECIFIED → const PublicKeyFieldName
Unspecified field name.
values → const List<PublicKeyFieldName>