displayName property
DisplayName is the public display name of the user. By default it's the user's given name and family name, their username or their email address.
Implementation
@$pb.TagNumber(3)
$core.String get displayName => $_getSZ(2);
Implementation
@$pb.TagNumber(3)
set displayName($core.String value) => $_setString(2, value);