Unit class

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
This enum's name, as specified in the .proto file.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
This enum's integer value, as specified in the .proto file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

valueOf(int value) → Unit?

Constants

UNIT_ACTIONS_ALL_RUN_SECONDS → const Unit
The sum of all actions run durations in seconds
UNIT_REQUESTS_ALL_AUTHENTICATED → const Unit
The sum of all requests to the Zitadel API with an authorization header, excluding the following exceptions
UNIT_UNIMPLEMENTED → const Unit
values → const List<Unit>