expirationDate property

  1. @TagNumber.new(8)
Timestamp get expirationDate

ExpirationDate is the time the session will be automatically invalidated. If not set, the session does not expire automatically.

Implementation

@$pb.TagNumber(8)
$0.Timestamp get expirationDate => $_getN(7);
  1. @TagNumber.new(8)
set expirationDate (Timestamp value)

Implementation

@$pb.TagNumber(8)
set expirationDate($0.Timestamp value) => $_setField(8, value);