loginName property

  1. @TagNumber.new(2)
String get loginName

The login name of the user to be checked. It will search case insensitive. Note this only checks for the computed login name and not for any organization scoped usernames. Also note that it will not check for emails or phone numbers, even if the corresponding setting is enabled. Use the user service ListUsers method to find a user by email or phone number first to obtain the user ID or login name.

Implementation

@$pb.TagNumber(2)
$core.String get loginName => $_getSZ(1);
  1. @TagNumber.new(2)
set loginName (String value)

Implementation

@$pb.TagNumber(2)
set loginName($core.String value) => $_setString(1, value);