Checks class

Available extensions

Constructors

Checks({CheckUser? user, CheckPassword? password, CheckWebAuthN? webAuthN, CheckIDPIntent? idpIntent, CheckTOTP? totp, CheckOTP? otpSms, CheckOTP? otpEmail, CheckRecoveryCode? recoveryCode})
factory
Checks.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
Checks.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
idpIntent CheckIDPIntent
Check the IDP intent and update the session on success. Requires that the user is already checked and an IDP intent succeeded and has not expired yet. Note that the IDP intent must be either matching the same user as checked in the session, or there must not be an external IDP linked to the intent's user. On successful IDP intent check, the session's factors field will be updated with an intent factor, containing the verification time.
getter/setter pair
info_ → BuilderInfo
no setter
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
otpEmail CheckOTP
Check the One-Time Password sent over Email and update the session on success. Requires that the user is already checked, either in the previous or the same request. On successful OTP Email check, the session's factors field will be updated with an otp factor, containing the verification time. Note that the OTP code is valid for a single use only and will be invalidated after a successful check.
getter/setter pair
otpSms CheckOTP
Check the One-Time Password sent over SMS and update the session on success. Requires that the user is already checked, either in the previous or the same request. On successful OTP SMS check, the session's factors field will be updated with an otp factor, containing the verification time. Note that the OTP code is valid for a single use only and will be invalidated after a successful check.
getter/setter pair
password CheckPassword
Check the password and update the session on success. Requires that the user is already checked, either in the previous or the same request. On successful password check, the session's factors field will be updated with a password factor, containing the verification time. On failed password check id: "COMMAND-3M0fs" wll be returned. On user locked out id: "COMMAND-JLK35"/"COMMAND-SFA3t" will be returned.
getter/setter pair
recoveryCode CheckRecoveryCode
Check the Recovery Code and update the session on success. Requires that the user is already checked, either in the previous or the same request. On successful Recovery Code check, the session's factors field will be updated with a recovery_code factor, containing the verification time.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totp CheckTOTP
Check the Time-based One-Time Password and update the session on success. Requires that the user is already checked, either in the previous or the same request. On successful TOTP check, the session's factors field will be updated with a totp factor, containing the verification time.
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited
user CheckUser
Check the user by its user ID or login name. A user check can only be performed once per session and cannot be changed afterwards. On successful user check, the session's factors field will be updated with a user factor containing the checked user's ID, login name, display name, organization ID and verification time. Note that some other checks require that the user is already checked, either in the previous or the same request. For example, a password check requires that the user is already checked.
getter/setter pair
webAuthN CheckWebAuthN
Check the public key credential issued by the WebAuthN client. Requires that the user is already checked and a WebAuthN challenge to be requested, in any previous request. On successful WebAuthN check, the session's factors field will be updated with a webauthn factor, containing the verification time and if the user presence was verified.
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearIdpIntent() → void
clearOtpEmail() → void
clearOtpSms() → void
clearPassword() → void
clearRecoveryCode() → void
clearTotp() → void
clearUser() → void
clearWebAuthN() → void
clone() Checks
Creates a deep copy of the fields in this message.
copyWith(void updates(Checks)) Checks
Apply updates to a copy of this message.
createEmptyInstance() Checks
Creates an empty instance of the same message type as this.
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
ensureIdpIntent() CheckIDPIntent
ensureOtpEmail() CheckOTP
ensureOtpSms() CheckOTP
ensurePassword() CheckPassword
ensureRecoveryCode() CheckRecoveryCode
ensureTotp() CheckTOTP
ensureUser() CheckUser
ensureWebAuthN() CheckWebAuthN
extensionsAreInitialized() bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasIdpIntent() bool
hasOtpEmail() bool
hasOtpSms() bool
hasPassword() bool
hasRecoveryCode() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasTotp() bool
hasUser() bool
hasWebAuthN() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create() Checks
getDefault() Checks