password property
Check the password and update the session on success.
Requires that the user is already checked, either in the previous or the same request.
On successful password check, the session's factors field will be updated with a password factor,
containing the verification time.
On failed password check id: "COMMAND-3M0fs" wll be returned.
On user locked out id: "COMMAND-JLK35"/"COMMAND-SFA3t" will be returned.
Implementation
@$pb.TagNumber(2)
CheckPassword get password => $_getN(1);
Implementation
@$pb.TagNumber(2)
set password(CheckPassword value) => $_setField(2, value);