recoveryCode property
Check the Recovery Code and update the session on success.
Requires that the user is already checked, either in the previous or the same request.
On successful Recovery Code check, the session's factors field will be updated with a recovery_code factor,
containing the verification time.
Implementation
@$pb.TagNumber(8)
CheckRecoveryCode get recoveryCode => $_getN(7);
Implementation
@$pb.TagNumber(8)
set recoveryCode(CheckRecoveryCode value) => $_setField(8, value);