totp property

  1. @TagNumber.new(5)
CheckTOTP get totp

Check the Time-based One-Time Password and update the session on success. Requires that the user is already checked, either in the previous or the same request. On successful TOTP check, the session's factors field will be updated with a totp factor, containing the verification time.

Implementation

@$pb.TagNumber(5)
CheckTOTP get totp => $_getN(4);
  1. @TagNumber.new(5)
set totp (CheckTOTP value)

Implementation

@$pb.TagNumber(5)
set totp(CheckTOTP value) => $_setField(5, value);