user property

  1. @TagNumber.new(1)
CheckUser get user

Check the user by its user ID or login name. A user check can only be performed once per session and cannot be changed afterwards. On successful user check, the session's factors field will be updated with a user factor containing the checked user's ID, login name, display name, organization ID and verification time. Note that some other checks require that the user is already checked, either in the previous or the same request. For example, a password check requires that the user is already checked.

Implementation

@$pb.TagNumber(1)
CheckUser get user => $_getN(0);
  1. @TagNumber.new(1)
set user (CheckUser value)

Implementation

@$pb.TagNumber(1)
set user(CheckUser value) => $_setField(1, value);