webAuthN property
Check the public key credential issued by the WebAuthN client.
Requires that the user is already checked and a WebAuthN challenge to be requested,
in any previous request.
On successful WebAuthN check, the session's factors field will be updated with a webauthn factor,
containing the verification time and if the user presence was verified.
Implementation
@$pb.TagNumber(3)
CheckWebAuthN get webAuthN => $_getN(2);
Implementation
@$pb.TagNumber(3)
set webAuthN(CheckWebAuthN value) => $_setField(3, value);