challenges property
Challenges to be requested for further verification. The challenges will be created and returned in the response. The challenges can then be used for further checks with the following SetSession method.
Implementation
@$pb.TagNumber(3)
$3.RequestChallenges get challenges => $_getN(2);
Implementation
@$pb.TagNumber(3)
set challenges($3.RequestChallenges value) => $_setField(3, value);