lifetime property
Duration after which the session will be automatically invalidated. If not set, the session will not expire automatically and must be deleted manually. Note that an expired session cannot be used for authentication anymore, but will still be listed until it is deleted.
Implementation
@$pb.TagNumber(5)
$4.Duration get lifetime => $_getN(4);
Implementation
@$pb.TagNumber(5)
set lifetime($4.Duration value) => $_setField(5, value);