sessionToken property

  1. @TagNumber.new(2)
String get sessionToken

The current token of the session, previously returned on the create / update request. The token is required unless either of the following conditions is met:

  • the caller created the session
  • the authenticated user requests their own session (checked user)
  • the security token provided in the authorization header has the same user agent as the session
  • the caller is granted the permission session.delete permission on either the instance or on the checked user's organization

Implementation

@$pb.TagNumber(2)
$core.String get sessionToken => $_getSZ(1);
  1. @TagNumber.new(2)
set sessionToken (String value)

Implementation

@$pb.TagNumber(2)
set sessionToken($core.String value) => $_setString(1, value);