sessionToken property
The current token of the session, previously returned on the create / update request. The token is required unless either of the following conditions is met:
- the caller created the session
- the authenticated user requests their own session (checked user)
- the security token provided in the authorization header has the same user agent as the session
- the caller is granted the permission session.read permission on either the instance or on the checked user's organization
Implementation
@$pb.TagNumber(2)
$core.String get sessionToken => $_getSZ(1);
Implementation
@$pb.TagNumber(2)
set sessionToken($core.String value) => $_setString(1, value);