sessions property

  1. @TagNumber.new(2)
PbList<Session> get sessions

The sessions matching the search query. There might be more sessions available than returned in this response. Use the details field to see if there are more sessions available and to get the total count of sessions matching the query.

Implementation

@$pb.TagNumber(2)
$pb.PbList<$2.Session> get sessions => $_getList(1);