createSession method

ResponseFuture<CreateSessionResponse> createSession(
  1. CreateSessionRequest request, {
  2. CallOptions? options,
})

Create Session

Create a new session with initial checks, metadata and challenges for further verification. A token will be returned, which is required for using the session as authentication, e.g. when authenticating an OIDC auth request or SAML request. Additionally, the session token can be used as OAuth2 access token to authenticate against the ZITADEL APIs.

Required permissions:

  • session.write

Implementation

$grpc.ResponseFuture<$0.CreateSessionResponse> createSession(
  $0.CreateSessionRequest request, {
  $grpc.CallOptions? options,
}) {
  return $createUnaryCall(_$createSession, request, options: options);
}