challenges property
Additional challenges to be requested for further verification. The challenges will be created and returned in the response. The challenges can then be used for further checks with the following SetSession method. Requesting a challenge that was already requested will overwrite the previous challenge.
Implementation
@$pb.TagNumber(5)
$3.RequestChallenges get challenges => $_getN(4);
Implementation
@$pb.TagNumber(5)
set challenges($3.RequestChallenges value) => $_setField(5, value);