lifetime property
Update the duration after which the session will be automatically invalidated. If not set, the lifetime will not be changed. Note that an expired session cannot be used for authentication anymore, but will still be listed until it is deleted.
Implementation
@$pb.TagNumber(6)
$4.Duration get lifetime => $_getN(5);
Implementation
@$pb.TagNumber(6)
set lifetime($4.Duration value) => $_setField(6, value);