metadata property
Additional custom key value pairs to be stored on the session. Existing keys will be overwritten. To delete a key, set its value to an empty byte array. Note that metadata keys cannot be changed once the session has been created. You need to create a new entry and delete the old one instead.
Implementation
@$pb.TagNumber(4)
$pb.PbMap<$core.String, $core.List<$core.int>> get metadata => $_getMap(3);