api/zitadel/settings library

Reexport of generated resources for the gRPC settings library.

Classes

DebugNotificationProvider
EmailProvider
EmailProviderHTTP
EmailProviderSMTP
EmailProviderState
HTTPConfig
OIDCSettings
SecretGenerator
SecretGeneratorQuery
SecretGeneratorType
SecretGeneratorTypeQuery
SecurityPolicy
SMSProvider
SMSProviderConfigState
SMTPConfig
SMTPConfigState
SMTPNoAuth
SMTPNoAuth can be used when no authentication is required for the SMTP connection.
SMTPPlainAuth
SMTPPlainAuth adds plain authentication to the smtp connection. The username of the parent configuration is used in combination with the password in this message.
SMTPXOAuth2Auth
SMTPXOAuth2Auth adds XOAut2 authentication to the smtp connection. The username of the parent configuration is used in combination with the other parameters of this message.
SMTPXOAuth2Auth_ClientCredentials
ClientCredentials authenticates the SMTP client using Oauth 2.0 Client Credentials grant. https://datatracker.ietf.org/doc/html/rfc6749#section-4.4
TwilioConfig

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.

Properties

debugNotificationProviderDescriptor Uint8List
Descriptor for DebugNotificationProvider. Decode as a google.protobuf.DescriptorProto.
final
emailProviderDescriptor Uint8List
Descriptor for EmailProvider. Decode as a google.protobuf.DescriptorProto.
final
emailProviderHTTPDescriptor Uint8List
Descriptor for EmailProviderHTTP. Decode as a google.protobuf.DescriptorProto.
final
emailProviderSMTPDescriptor Uint8List
Descriptor for EmailProviderSMTP. Decode as a google.protobuf.DescriptorProto.
final
emailProviderStateDescriptor Uint8List
Descriptor for EmailProviderState. Decode as a google.protobuf.EnumDescriptorProto.
final
hTTPConfigDescriptor Uint8List
Descriptor for HTTPConfig. Decode as a google.protobuf.DescriptorProto.
final
oIDCSettingsDescriptor Uint8List
Descriptor for OIDCSettings. Decode as a google.protobuf.DescriptorProto.
final
secretGeneratorDescriptor Uint8List
Descriptor for SecretGenerator. Decode as a google.protobuf.DescriptorProto.
final
secretGeneratorQueryDescriptor Uint8List
Descriptor for SecretGeneratorQuery. Decode as a google.protobuf.DescriptorProto.
final
secretGeneratorTypeDescriptor Uint8List
Descriptor for SecretGeneratorType. Decode as a google.protobuf.EnumDescriptorProto.
final
secretGeneratorTypeQueryDescriptor Uint8List
Descriptor for SecretGeneratorTypeQuery. Decode as a google.protobuf.DescriptorProto.
final
securityPolicyDescriptor Uint8List
Descriptor for SecurityPolicy. Decode as a google.protobuf.DescriptorProto.
final
sMSProviderConfigStateDescriptor Uint8List
Descriptor for SMSProviderConfigState. Decode as a google.protobuf.EnumDescriptorProto.
final
sMSProviderDescriptor Uint8List
Descriptor for SMSProvider. Decode as a google.protobuf.DescriptorProto.
final
sMTPConfigDescriptor Uint8List
Descriptor for SMTPConfig. Decode as a google.protobuf.DescriptorProto.
final
sMTPConfigStateDescriptor Uint8List
Descriptor for SMTPConfigState. Decode as a google.protobuf.EnumDescriptorProto.
final
sMTPNoAuthDescriptor Uint8List
Descriptor for SMTPNoAuth. Decode as a google.protobuf.DescriptorProto.
final
sMTPPlainAuthDescriptor Uint8List
Descriptor for SMTPPlainAuth. Decode as a google.protobuf.DescriptorProto.
final
sMTPXOAuth2AuthDescriptor Uint8List
Descriptor for SMTPXOAuth2Auth. Decode as a google.protobuf.DescriptorProto.
final
twilioConfigDescriptor Uint8List
Descriptor for TwilioConfig. Decode as a google.protobuf.DescriptorProto.
final