allowedLanguages property

  1. @TagNumber.new(5)
PbList<String> get allowedLanguages

The list of allowed languages for the instance. This is a subset of the supported languages to be used in the instance e.g. for user selection during registration or language detection in the UI. The format is a BCP 47 language tag (e.g. "en", "de", "fr-CH").

Implementation

@$pb.TagNumber(5)
$pb.PbList<$core.String> get allowedLanguages => $_getList(4);