defaultOrganizationId property
The unique identifier of the default organization. The default organization is used to assign new users to an organization if no other organization is specified.
Implementation
@$pb.TagNumber(4)
$core.String get defaultOrganizationId => $_getSZ(3);
Implementation
@$pb.TagNumber(4)
set defaultOrganizationId($core.String value) => $_setString(3, value);