supportedLanguages property

  1. @TagNumber.new(3)
PbList<String> get supportedLanguages

The list of supported languages. Note that the instance might restrict the languages further only allowing a subset of these languages to be used. The format is a BCP 47 language tag (e.g. "en", "de", "fr-CH").

Implementation

@$pb.TagNumber(3)
$pb.PbList<$core.String> get supportedLanguages => $_getList(2);