ignoreInheritance property

  1. @TagNumber.new(5)
bool get ignoreInheritance

if set to true, higher levels are ignored, if false higher levels are merged into the file

Implementation

@$pb.TagNumber(5)
$core.bool get ignoreInheritance => $_getBF(4);
  1. @TagNumber.new(5)
set ignoreInheritance (bool value)

Implementation

@$pb.TagNumber(5)
set ignoreInheritance($core.bool value) => $_setBool(4, value);