SettingsServiceBase class abstract

Annotations
  • @GrpcServiceName.new('zitadel.settings.v2.SettingsService')

Constructors

SettingsServiceBase()

Properties

$name → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
deleteOrganizationSettings(ServiceCall call, DeleteOrganizationSettingsRequest request) → Future<DeleteOrganizationSettingsResponse>
deleteOrganizationSettings_Pre(ServiceCall $call, Future<DeleteOrganizationSettingsRequest> $request) → Future<DeleteOrganizationSettingsResponse>
getActiveIdentityProviders(ServiceCall call, GetActiveIdentityProvidersRequest request) → Future<GetActiveIdentityProvidersResponse>
getActiveIdentityProviders_Pre(ServiceCall $call, Future<GetActiveIdentityProvidersRequest> $request) → Future<GetActiveIdentityProvidersResponse>
getBrandingSettings(ServiceCall call, GetBrandingSettingsRequest request) → Future<GetBrandingSettingsResponse>
getBrandingSettings_Pre(ServiceCall $call, Future<GetBrandingSettingsRequest> $request) → Future<GetBrandingSettingsResponse>
getDomainSettings(ServiceCall call, GetDomainSettingsRequest request) → Future<GetDomainSettingsResponse>
getDomainSettings_Pre(ServiceCall $call, Future<GetDomainSettingsRequest> $request) → Future<GetDomainSettingsResponse>
getGeneralSettings(ServiceCall call, GetGeneralSettingsRequest request) → Future<GetGeneralSettingsResponse>
getGeneralSettings_Pre(ServiceCall $call, Future<GetGeneralSettingsRequest> $request) → Future<GetGeneralSettingsResponse>
getHostedLoginTranslation(ServiceCall call, GetHostedLoginTranslationRequest request) → Future<GetHostedLoginTranslationResponse>
getHostedLoginTranslation_Pre(ServiceCall $call, Future<GetHostedLoginTranslationRequest> $request) → Future<GetHostedLoginTranslationResponse>
getLegalAndSupportSettings(ServiceCall call, GetLegalAndSupportSettingsRequest request) → Future<GetLegalAndSupportSettingsResponse>
getLegalAndSupportSettings_Pre(ServiceCall $call, Future<GetLegalAndSupportSettingsRequest> $request) → Future<GetLegalAndSupportSettingsResponse>
getLockoutSettings(ServiceCall call, GetLockoutSettingsRequest request) → Future<GetLockoutSettingsResponse>
getLockoutSettings_Pre(ServiceCall $call, Future<GetLockoutSettingsRequest> $request) → Future<GetLockoutSettingsResponse>
getLoginSettings(ServiceCall call, GetLoginSettingsRequest request) → Future<GetLoginSettingsResponse>
getLoginSettings_Pre(ServiceCall $call, Future<GetLoginSettingsRequest> $request) → Future<GetLoginSettingsResponse>
getPasswordComplexitySettings(ServiceCall call, GetPasswordComplexitySettingsRequest request) → Future<GetPasswordComplexitySettingsResponse>
getPasswordComplexitySettings_Pre(ServiceCall $call, Future<GetPasswordComplexitySettingsRequest> $request) → Future<GetPasswordComplexitySettingsResponse>
getPasswordExpirySettings(ServiceCall call, GetPasswordExpirySettingsRequest request) → Future<GetPasswordExpirySettingsResponse>
getPasswordExpirySettings_Pre(ServiceCall $call, Future<GetPasswordExpirySettingsRequest> $request) → Future<GetPasswordExpirySettingsResponse>
getSecuritySettings(ServiceCall call, GetSecuritySettingsRequest request) → Future<GetSecuritySettingsResponse>
getSecuritySettings_Pre(ServiceCall $call, Future<GetSecuritySettingsRequest> $request) → Future<GetSecuritySettingsResponse>
listOrganizationSettings(ServiceCall call, ListOrganizationSettingsRequest request) → Future<ListOrganizationSettingsResponse>
listOrganizationSettings_Pre(ServiceCall $call, Future<ListOrganizationSettingsRequest> $request) → Future<ListOrganizationSettingsResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setHostedLoginTranslation(ServiceCall call, SetHostedLoginTranslationRequest request) → Future<SetHostedLoginTranslationResponse>
setHostedLoginTranslation_Pre(ServiceCall $call, Future<SetHostedLoginTranslationRequest> $request) → Future<SetHostedLoginTranslationResponse>
setOrganizationSettings(ServiceCall call, SetOrganizationSettingsRequest request) → Future<SetOrganizationSettingsResponse>
setOrganizationSettings_Pre(ServiceCall $call, Future<SetOrganizationSettingsRequest> $request) → Future<SetOrganizationSettingsResponse>
setSecuritySettings(ServiceCall call, SetSecuritySettingsRequest request) → Future<SetSecuritySettingsResponse>
setSecuritySettings_Pre(ServiceCall $call, Future<SetSecuritySettingsRequest> $request) → Future<SetSecuritySettingsResponse>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited