SettingsServiceClient class

Annotations
  • @GrpcServiceName.new('zitadel.settings.v2.SettingsService')

Constructors

SettingsServiceClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R>
inherited
deleteOrganizationSettings(DeleteOrganizationSettingsRequest request, {CallOptions? options}) → ResponseFuture<DeleteOrganizationSettingsResponse>
Delete Organization Settings
getActiveIdentityProviders(GetActiveIdentityProvidersRequest request, {CallOptions? options}) → ResponseFuture<GetActiveIdentityProvidersResponse>
Get Active Identity Providers
getBrandingSettings(GetBrandingSettingsRequest request, {CallOptions? options}) → ResponseFuture<GetBrandingSettingsResponse>
Get Branding Settings
getDomainSettings(GetDomainSettingsRequest request, {CallOptions? options}) → ResponseFuture<GetDomainSettingsResponse>
Get Domain Settings
getGeneralSettings(GetGeneralSettingsRequest request, {CallOptions? options}) → ResponseFuture<GetGeneralSettingsResponse>
Get General Settings
getHostedLoginTranslation(GetHostedLoginTranslationRequest request, {CallOptions? options}) → ResponseFuture<GetHostedLoginTranslationResponse>
Get Hosted Login Translation
getLegalAndSupportSettings(GetLegalAndSupportSettingsRequest request, {CallOptions? options}) → ResponseFuture<GetLegalAndSupportSettingsResponse>
Get Legal and Support Settings
getLockoutSettings(GetLockoutSettingsRequest request, {CallOptions? options}) → ResponseFuture<GetLockoutSettingsResponse>
Get Lockout Settings
getLoginSettings(GetLoginSettingsRequest request, {CallOptions? options}) → ResponseFuture<GetLoginSettingsResponse>
Get Login Settings
getPasswordComplexitySettings(GetPasswordComplexitySettingsRequest request, {CallOptions? options}) → ResponseFuture<GetPasswordComplexitySettingsResponse>
Get Password Complexity Settings
getPasswordExpirySettings(GetPasswordExpirySettingsRequest request, {CallOptions? options}) → ResponseFuture<GetPasswordExpirySettingsResponse>
Get Password Expiry Settings
getSecuritySettings(GetSecuritySettingsRequest request, {CallOptions? options}) → ResponseFuture<GetSecuritySettingsResponse>
Get Security Settings
listOrganizationSettings(ListOrganizationSettingsRequest request, {CallOptions? options}) → ResponseFuture<ListOrganizationSettingsResponse>
List Organization Settings
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setHostedLoginTranslation(SetHostedLoginTranslationRequest request, {CallOptions? options}) → ResponseFuture<SetHostedLoginTranslationResponse>
Set Hosted Login Translation
setOrganizationSettings(SetOrganizationSettingsRequest request, {CallOptions? options}) → ResponseFuture<SetOrganizationSettingsResponse>
Set Organization Settings
setSecuritySettings(SetSecuritySettingsRequest request, {CallOptions? options}) → ResponseFuture<SetSecuritySettingsResponse>
Set Security Settings
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultHost → const String
The hostname for this service.
oauthScopes → const List<String>
OAuth scopes needed for the client.