getDomainSettings method

ResponseFuture<GetDomainSettingsResponse> getDomainSettings(
  1. GetDomainSettingsRequest request, {
  2. CallOptions? options,
})

Get Domain Settings

Get the domain settings for the requested context. This can be the instance or an organization. In case of an organization, the returned settings will fall back to the instance settings if not explicitly set on the organization.

Required permissions:

  • policy.read

Implementation

$grpc.ResponseFuture<$0.GetDomainSettingsResponse> getDomainSettings(
  $0.GetDomainSettingsRequest request, {
  $grpc.CallOptions? options,
}) {
  return $createUnaryCall(_$getDomainSettings, request, options: options);
}