getLegalAndSupportSettings method

ResponseFuture<GetLegalAndSupportSettingsResponse> getLegalAndSupportSettings(
  1. GetLegalAndSupportSettingsRequest request, {
  2. CallOptions? options,
})

Get Legal and Support Settings

Get the legal and support settings for the requested context. This can be the instance or an organization. In case of an organization, the returned settings will fall back to the instance settings if not explicitly set on the organization.

Required permissions:

  • policy.read

Implementation

$grpc.ResponseFuture<$0.GetLegalAndSupportSettingsResponse>
    getLegalAndSupportSettings(
  $0.GetLegalAndSupportSettingsRequest request, {
  $grpc.CallOptions? options,
}) {
  return $createUnaryCall(_$getLegalAndSupportSettings, request,
      options: options);
}