getPasswordComplexitySettings method
ResponseFuture<GetPasswordComplexitySettingsResponse>
getPasswordComplexitySettings(
- GetPasswordComplexitySettingsRequest request, {
- CallOptions? options,
Get Password Complexity Settings
Get the password complexity settings for the requested context. This can be the instance or an organization. In case of an organization, the returned settings will fall back to the instance settings if not explicitly set on the organization.
Required permissions:
policy.read
Implementation
$grpc.ResponseFuture<$0.GetPasswordComplexitySettingsResponse>
getPasswordComplexitySettings(
$0.GetPasswordComplexitySettingsRequest request, {
$grpc.CallOptions? options,
}) {
return $createUnaryCall(_$getPasswordComplexitySettings, request,
options: options);
}