oidcTokenExchange property

  1. @Deprecated('This field is deprecated.')
  2. @TagNumber.new(5)
bool get oidcTokenExchange

Deprecated: the flag has been removed and urn:ietf:params:oauth:grant-type:token-exchange grant type for the OIDC token endpoint is enabled by default. Token exchange can be used to request tokens with a lesser scope or impersonate other users. See the security policy to allow impersonation on an instance. This field is only kept for backward compatibility and will be removed in the next major version of Zitadel. Setting the field will have no effect.

Implementation

@$core.Deprecated('This field is deprecated.')
@$pb.TagNumber(5)
$core.bool get oidcTokenExchange => $_getBF(2);
  1. @Deprecated('This field is deprecated.')
  2. @TagNumber.new(5)
set oidcTokenExchange (bool value)

Implementation

@$core.Deprecated('This field is deprecated.')
@$pb.TagNumber(5)
set oidcTokenExchange($core.bool value) => $_setBool(2, value);