PAYLOAD_TYPE_JWT constant

PayloadType const PAYLOAD_TYPE_JWT

PAYLOAD_TYPE_JWT will send the payload as JSON Web Token (JWT) in the body of the request. This allows the receiver to verify the authenticity and integrity of the payload using the signing key (published on the JWKS URL).

Implementation

static const PayloadType PAYLOAD_TYPE_JWT =
    PayloadType._(2, _omitEnumNames ? '' : 'PAYLOAD_TYPE_JWT');