fingerprint property

  1. @TagNumber.new(4)
String get fingerprint

Fingerprint is the fingerprint of the public key. It's prefixed with the hashing algorithm used and base64 encoded without padding, e.g. SHA256:STqK+Sd4qgdu+UjiwI8NBjOD6P7UqQ42EZYIdySEyTw. The fingerprint can be used to easily compare the public key with other sources.

Implementation

@$pb.TagNumber(4)
$core.String get fingerprint => $_getSZ(3);
  1. @TagNumber.new(4)
set fingerprint (String value)

Implementation

@$pb.TagNumber(4)
set fingerprint($core.String value) => $_setString(3, value);