keyId property

  1. @TagNumber.new(1)
String get keyId

KeyID is the unique identifier of the public key. It's also used as the kid field in the JWE header when the payload type is set to PAYLOAD_TYPE_JWE.

Implementation

@$pb.TagNumber(1)
$core.String get keyId => $_getSZ(0);
  1. @TagNumber.new(1)
set keyId (String value)

Implementation

@$pb.TagNumber(1)
set keyId($core.String value) => $_setString(0, value);