api/zitadel/analytics/v2beta/telemetry_service library

Reexport of generated resources for the gRPC telemetry_service library.

Classes

ReportBaseInformationRequest
ReportBaseInformationResponse
ReportResourceCountsRequest
ReportResourceCountsResponse
TelemetryServiceBase
TelemetryServiceClient
The TelemetryService is used to report telemetry such as usage statistics of the Zitadel instance(s). back to a central storage. It is used to collect anonymized data about the usage of Zitadel features, capabilities, and configurations. Zitadel acts as a client of the TelemetryService.

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.

Properties

reportBaseInformationRequestDescriptor Uint8List
Descriptor for ReportBaseInformationRequest. Decode as a google.protobuf.DescriptorProto.
final
reportBaseInformationResponseDescriptor Uint8List
Descriptor for ReportBaseInformationResponse. Decode as a google.protobuf.DescriptorProto.
final
reportResourceCountsRequestDescriptor Uint8List
Descriptor for ReportResourceCountsRequest. Decode as a google.protobuf.DescriptorProto.
final
reportResourceCountsResponseDescriptor Uint8List
Descriptor for ReportResourceCountsResponse. Decode as a google.protobuf.DescriptorProto.
final