givenName property
The given name is the first name of the user
Implementation
@$pb.TagNumber(1)
$core.String get givenName => $_getSZ(0);
Implementation
@$pb.TagNumber(1)
set givenName($core.String value) => $_setString(0, value);
The given name is the first name of the user
@$pb.TagNumber(1)
$core.String get givenName => $_getSZ(0);
@$pb.TagNumber(1)
set givenName($core.String value) => $_setString(0, value);