searchUserSchemas method

ResponseFuture<SearchUserSchemasResponse> searchUserSchemas(
  1. SearchUserSchemasRequest request, {
  2. CallOptions? options,
})

Search user schemas

Search all matching user schemas. By default, we will return all user schema of your instance. Make sure to include a limit and sorting for pagination.

Implementation

$grpc.ResponseFuture<$0.SearchUserSchemasResponse> searchUserSchemas(
  $0.SearchUserSchemasRequest request, {
  $grpc.CallOptions? options,
}) {
  return $createUnaryCall(_$searchUserSchemas, request, options: options);
}