AddHumanUserRequest class

Available extensions

Constructors

AddHumanUserRequest({String? userId, String? username, SetHumanProfile? profile, SetHumanEmail? email, Iterable<SetMetadataEntry>? metadata, Password? password, HashedPassword? hashedPassword, Iterable<IDPLink>? idpLinks, SetHumanPhone? phone, Organization? organization, String? totpSecret})
factory
AddHumanUserRequest.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
AddHumanUserRequest.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

email ↔ SetHumanEmail
getter/setter pair
hashCode → int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
hashedPassword ↔ HashedPassword
getter/setter pair
no setter
info_ → BuilderInfo
no setter
isFrozen → bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
metadata → PbList<SetMetadataEntry>
no setter
organization ↔ Organization
getter/setter pair
password ↔ Password
getter/setter pair
phone ↔ SetHumanPhone
getter/setter pair
profile ↔ SetHumanProfile
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totpSecret ↔ String
An Implementation of RFC 6238 is used, with HMAC-SHA-1 and time-step of 30 seconds. Currently no other options are supported, and if anything different is used the validation will fail.
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited
userId ↔ String
optionally set your own id unique for the user.
getter/setter pair
username ↔ String
optionally set a unique username, if none is provided the email will be used.
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearEmail() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearHashedPassword() → void
clearOrganization() → void
clearPassword() → void
clearPasswordType() → void
clearPhone() → void
clearProfile() → void
clearTotpSecret() → void
clearUserId() → void
clearUsername() → void
clone() → AddHumanUserRequest
Creates a deep copy of the fields in this message.
copyWith(void updates(AddHumanUserRequest)) → AddHumanUserRequest
Apply updates to a copy of this message.
createEmptyInstance() → AddHumanUserRequest
Creates an empty instance of the same message type as this.
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
ensureEmail() → SetHumanEmail
ensureHashedPassword() → HashedPassword
ensureOrganization() → Organization
ensurePassword() → Password
ensurePhone() → SetHumanPhone
ensureProfile() → SetHumanProfile
extensionsAreInitialized() → bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) → int?
inherited
hasEmail() → bool
hasExtension(Extension extension) → bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) → bool
Whether this message has a field associated with tagNumber.
inherited
hasHashedPassword() → bool
hasOrganization() → bool
hasPassword() → bool
hasPhone() → bool
hasProfile() → bool
hasRequiredFields() → bool
Whether the message has required fields.
inherited
hasTotpSecret() → bool
hasUserId() → bool
hasUsername() → bool
isInitialized() → bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() → String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() → String
Returns a String representation of this message.
inherited
whichPasswordType() → AddHumanUserRequest_PasswordType
writeToBuffer() → Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() → String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() → Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited