keyContent property
The key which is usable to authenticate against the API.
Implementation
@$pb.TagNumber(3)
$core.List<$core.int> get keyContent => $_getN(2);
The key which is usable to authenticate against the API.
@$pb.TagNumber(3)
$core.List<$core.int> get keyContent => $_getN(2);