human property

  1. @TagNumber.new(4)
CreateUserRequest_Human get human

Users of type human are users that are meant to be used by a person. They can log in interactively using a login UI. By default, new users will receive a verification email and, if a phone is configured, a verification SMS. To make sure these messages are sent, configure and activate valid SMTP and Twilio configurations. Read more about your options for controlling this behaviour in the email and phone field documentations.

Implementation

@$pb.TagNumber(4)
CreateUserRequest_Human get human => $_getN(3);
  1. @TagNumber.new(4)
set human (CreateUserRequest_Human value)

Implementation

@$pb.TagNumber(4)
set human(CreateUserRequest_Human value) => $_setField(4, value);