machine property
Users of type machine are users that are meant to be used by a machine. In order to authenticate, add a secret, a key or a personal access token to the user. Tokens generated for new users of type machine will be of an opaque Bearer type. You can change the users token type to JWT by using the management v1 service method UpdateMachine.
Implementation
@$pb.TagNumber(5)
CreateUserRequest_Machine get machine => $_getN(4);
Implementation
@$pb.TagNumber(5)
set machine(CreateUserRequest_Machine value) => $_setField(5, value);