userId property

  1. @TagNumber.new(2)
String get userId

The ID is a unique identifier for the user in the instance. If not specified, it will be generated. You can set your own user id that is unique within the instance. This is useful in migration scenarios, for example if the user already has an ID in another Zitadel system. If not specified, it will be generated. It can't be changed after creation.

Implementation

@$pb.TagNumber(2)
$core.String get userId => $_getSZ(1);
  1. @TagNumber.new(2)
set userId (String value)

Implementation

@$pb.TagNumber(2)
set userId($core.String value) => $_setString(1, value);