username property

  1. @TagNumber.new(3)
String get username

The username is a unique identifier for the user in the organization. If not specified, Zitadel sets the username to the email for users of type human and to the user_id for users of type machine. It is used to identify the user in the organization and can be used for login.

Implementation

@$pb.TagNumber(3)
$core.String get username => $_getSZ(2);
  1. @TagNumber.new(3)
set username (String value)

Implementation

@$pb.TagNumber(3)
set username($core.String value) => $_setString(2, value);