idpLinks property
Create the user with a list of links to identity providers. This can be useful in migration-scenarios. For example, if a user already has an account in an external identity provider or another Zitadel instance, an IDP link allows the user to authenticate as usual. Sessions, second factors, hardware keys registered externally are still available for authentication. Use the following endpoints to manage identity provider links:
Implementation
@$pb.TagNumber(7)
$pb.PbList<$4.IDPLink> get idpLinks => $_getList(5);