phone property
Set the users phone number and optionally send a verification SMS.
Implementation
@$pb.TagNumber(3)
$5.SetHumanPhone get phone => $_getN(2);
Implementation
@$pb.TagNumber(3)
set phone($5.SetHumanPhone value) => $_setField(3, value);
Set the users phone number and optionally send a verification SMS.
@$pb.TagNumber(3)
$5.SetHumanPhone get phone => $_getN(2);
@$pb.TagNumber(3)
set phone($5.SetHumanPhone value) => $_setField(3, value);