accessTokenType property
The access token type defines the type of access token that is generated for the user. By default, the access token type is an opaque Bearer token. You can change it to JWT, which will include more information about the user and their permissions in the token itself. This can be useful for machine users that need to call services that require more information about the user, without having to call the userinfo or introspection endpoint. However, revoked JWTs may still be considered valid until they expire. Always call the userinfo or introspection endpoint to verify that a JWT is still valid.
Implementation
@$pb.TagNumber(3)
$1.AccessTokenType get accessTokenType => $_getN(2);
Implementation
@$pb.TagNumber(3)
set accessTokenType($1.AccessTokenType value) => $_setField(3, value);