UpdateUserRequest_Human_Profile class

Available extensions

Constructors

UpdateUserRequest_Human_Profile({String? givenName, String? familyName, String? nickName, String? displayName, String? preferredLanguage, Gender? gender})
factory
UpdateUserRequest_Human_Profile.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
UpdateUserRequest_Human_Profile.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

displayName String
The display name is how a user should primarily be displayed in lists. It can also for example be used to personalize user interfaces and notifications.
getter/setter pair
familyName String
The family name is the last name of the user. For example, it can be used to personalize user interfaces and notifications.
getter/setter pair
gender Gender
The users gender can for example be used to personalize user interfaces and notifications.
getter/setter pair
givenName String
The given name is the first name of the user. For example, it can be used to personalize notifications and login UIs.
getter/setter pair
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setter
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
nickName String
The nick name is the users short name. For example, it can be used to personalize user interfaces and notifications.
getter/setter pair
preferredLanguage String
The users preferred language is the language that systems should use to interact with the user. It has the format of a BCP-47 language tag. It is used by Zitadel where no higher prioritized preferred language can be used. For example, browser settings can overwrite a users preferred_language. Notification messages and standard login UIs use the users preferred language if it is supported and allowed on the instance. Else, the default language of the instance is used.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unknownFields → UnknownFieldSet
no setterinherited

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearDisplayName() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearFamilyName() → void
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearGender() → void
clearGivenName() → void
clearNickName() → void
clearPreferredLanguage() → void
clone() UpdateUserRequest_Human_Profile
Creates a deep copy of the fields in this message.
copyWith(void updates(UpdateUserRequest_Human_Profile)) UpdateUserRequest_Human_Profile
Apply updates to a copy of this message.
createEmptyInstance() UpdateUserRequest_Human_Profile
Creates an empty instance of the same message type as this.
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
extensionsAreInitialized() bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasDisplayName() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasFamilyName() bool
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasGender() bool
hasGivenName() bool
hasNickName() bool
hasPreferredLanguage() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited