givenName property
The given name is the first name of the user. For example, it can be used to personalize notifications and login UIs.
Implementation
@$pb.TagNumber(1)
$core.String get givenName => $_getSZ(0);
Implementation
@$pb.TagNumber(1)
set givenName($core.String value) => $_setString(0, value);