addHumanUser method
ResponseFuture<AddHumanUserResponse>
addHumanUser(
- AddHumanUserRequest request, {
- CallOptions? options,
Create a new User (Human)
Deprecated: Use CreateUser to create a new user.
Create/import a new user. The newly created user will get a verification email if either the email address is not marked as verified and you did not request the verification to be returned.
Implementation
$grpc.ResponseFuture<$0.AddHumanUserResponse> addHumanUser(
$0.AddHumanUserRequest request, {
$grpc.CallOptions? options,
}) {
return $createUnaryCall(_$addHumanUser, request, options: options);
}