addSecret method
Add a Users Secret
Generates a client secret for the user. The client id is the users username. If the user already has a secret, it is overwritten. Only users of type machine can have a secret.
Required permission:
- user.write
Implementation
$grpc.ResponseFuture<$0.AddSecretResponse> addSecret(
$0.AddSecretRequest request, {
$grpc.CallOptions? options,
}) {
return $createUnaryCall(_$addSecret, request, options: options);
}