registerTOTP method
ResponseFuture<RegisterTOTPResponse>
registerTOTP(
- RegisterTOTPRequest request, {
- CallOptions? options,
Start the registration of a TOTP generator for a user
Start the registration of a TOTP generator for a user, as a response a secret returned, which is used to initialize a TOTP app or device..
Implementation
$grpc.ResponseFuture<$0.RegisterTOTPResponse> registerTOTP(
$0.RegisterTOTPRequest request, {
$grpc.CallOptions? options,
}) {
return $createUnaryCall(_$registerTOTP, request, options: options);
}