setEmail method
Change the user email
Deprecated: Update the users email field.
Change the email address of a user. If the state is set to not verified, a verification code will be generated, which can be either returned or sent to the user by email..
Implementation
$grpc.ResponseFuture<$0.SetEmailResponse> setEmail(
$0.SetEmailRequest request, {
$grpc.CallOptions? options,
}) {
return $createUnaryCall(_$setEmail, request, options: options);
}