setPhone method

ResponseFuture<SetPhoneResponse> setPhone(
  1. SetPhoneRequest request, {
  2. CallOptions? options,
})

Set the user phone

Deprecated: Update the users phone field.

Set the phone number of a user. If the state is set to not verified, a verification code will be generated, which can be either returned or sent to the user by sms..

Implementation

$grpc.ResponseFuture<$0.SetPhoneResponse> setPhone(
  $0.SetPhoneRequest request, {
  $grpc.CallOptions? options,
}) {
  return $createUnaryCall(_$setPhone, request, options: options);
}