setUserMetadata method
ResponseFuture<SetUserMetadataResponse>
setUserMetadata(
- SetUserMetadataRequest request, {
- CallOptions? options,
Set User Metadata
Sets a list of key value pairs. Existing metadata entries with matching keys are overwritten. Existing metadata entries without matching keys are untouched. To remove existing metadata entries, pass an empty metadata value or use DeleteUserMetadata. If no metadata entry exists for a given key, passing an empty value for that key has no effect (no-op). For HTTP requests, make sure the bytes array value is base64 encoded.
Required permission:
user.write
Implementation
$grpc.ResponseFuture<$0.SetUserMetadataResponse> setUserMetadata(
$0.SetUserMetadataRequest request, {
$grpc.CallOptions? options,
}) {
return $createUnaryCall(_$setUserMetadata, request, options: options);
}