updateUser method
ResponseFuture<UpdateUserResponse>
updateUser(
- UpdateUserRequest request, {
- CallOptions? options,
Update a User
Partially update an existing user. If you change the users email or phone, you can specify how the ownership should be verified. If you change the users password, you can specify if the password should be changed again on the users next login.
Required permission:
- user.write
Implementation
$grpc.ResponseFuture<$0.UpdateUserResponse> updateUser(
$0.UpdateUserRequest request, {
$grpc.CallOptions? options,
}) {
return $createUnaryCall(_$updateUser, request, options: options);
}