addOTPEmailAuthenticator method

ResponseFuture<AddOTPEmailAuthenticatorResponse> addOTPEmailAuthenticator(
  1. AddOTPEmailAuthenticatorRequest request, {
  2. CallOptions? options,
})

Add a OTP Email authenticator

Add a new one-time password (OTP) Email authenticator to a user. If the email is not passed as verified, a verification code will be generated, which can be either returned or will be sent to the user by email.

Implementation

$grpc.ResponseFuture<$0.AddOTPEmailAuthenticatorResponse>
    addOTPEmailAuthenticator(
  $0.AddOTPEmailAuthenticatorRequest request, {
  $grpc.CallOptions? options,
}) {
  return $createUnaryCall(_$addOTPEmailAuthenticator, request,
      options: options);
}