DataOrg class

Available extensions

Constructors

DataOrg({String? orgId, AddOrgRequest? org, AddCustomOrgIAMPolicyRequest? iamPolicy, AddCustomLabelPolicyRequest? labelPolicy, AddCustomLockoutPolicyRequest? lockoutPolicy, AddCustomLoginPolicyRequest? loginPolicy, AddCustomPasswordComplexityPolicyRequest? passwordComplexityPolicy, AddCustomPrivacyPolicyRequest? privacyPolicy, Iterable<DataProject>? projects, Iterable<AddProjectRoleRequest>? projectRoles, Iterable<DataAPIApplication>? apiApps, Iterable<DataOIDCApplication>? oidcApps, Iterable<DataHumanUser>? humanUsers, Iterable<DataMachineUser>? machineUsers, Iterable<SetTriggerActionsRequest>? triggerActions, Iterable<DataAction>? actions, Iterable<DataProjectGrant>? projectGrants, Iterable<AddUserGrantRequest>? userGrants, Iterable<AddOrgMemberRequest>? orgMembers, Iterable<AddProjectMemberRequest>? projectMembers, Iterable<AddProjectGrantMemberRequest>? projectGrantMembers, Iterable<SetUserMetadataRequest>? userMetadata, Iterable<SetCustomLoginTextsRequest>? loginTexts, Iterable<SetCustomInitMessageTextRequest>? initMessages, Iterable<SetCustomPasswordResetMessageTextRequest>? passwordResetMessages, Iterable<SetCustomVerifyEmailMessageTextRequest>? verifyEmailMessages, Iterable<SetCustomVerifyPhoneMessageTextRequest>? verifyPhoneMessages, Iterable<SetCustomDomainClaimedMessageTextRequest>? domainClaimedMessages, Iterable<SetCustomPasswordlessRegistrationMessageTextRequest>? passwordlessRegistrationMessages, Iterable<DataOIDCIDP>? oidcIdps, Iterable<DataJWTIDP>? jwtIdps, Iterable<AddSecondFactorToLoginPolicyRequest>? secondFactors, Iterable<AddMultiFactorToLoginPolicyRequest>? multiFactors, Iterable<AddIDPToLoginPolicyRequest>? idps, Iterable<IDPUserLink>? userLinks, Iterable<Domain>? domains, Iterable<DataAppKey>? appKeys, Iterable<DataMachineKey>? machineKeys, Iterable<SetCustomInviteUserMessageTextRequest>? inviteUserMessages})
factory
DataOrg.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
DataOrg.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

actions → PbList<DataAction>
no setter
apiApps → PbList<DataAPIApplication>
no setter
appKeys → PbList<DataAppKey>
no setter
domainClaimedMessages → PbList<SetCustomDomainClaimedMessageTextRequest>
no setter
domains → PbList<Domain>
no setter
hashCode → int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
humanUsers → PbList<DataHumanUser>
no setter
iamPolicy ↔ AddCustomOrgIAMPolicyRequest
getter/setter pair
idps → PbList<AddIDPToLoginPolicyRequest>
no setter
info_ → BuilderInfo
no setter
initMessages → PbList<SetCustomInitMessageTextRequest>
no setter
inviteUserMessages → PbList<SetCustomInviteUserMessageTextRequest>
no setter
isFrozen → bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
jwtIdps → PbList<DataJWTIDP>
no setter
labelPolicy ↔ AddCustomLabelPolicyRequest
getter/setter pair
lockoutPolicy ↔ AddCustomLockoutPolicyRequest
getter/setter pair
loginPolicy ↔ AddCustomLoginPolicyRequest
getter/setter pair
loginTexts → PbList<SetCustomLoginTextsRequest>
no setter
machineKeys → PbList<DataMachineKey>
no setter
machineUsers → PbList<DataMachineUser>
no setter
multiFactors → PbList<AddMultiFactorToLoginPolicyRequest>
no setter
oidcApps → PbList<DataOIDCApplication>
no setter
oidcIdps → PbList<DataOIDCIDP>
no setter
org ↔ AddOrgRequest
getter/setter pair
orgId ↔ String
getter/setter pair
orgMembers → PbList<AddOrgMemberRequest>
no setter
passwordComplexityPolicy ↔ AddCustomPasswordComplexityPolicyRequest
getter/setter pair
passwordlessRegistrationMessages → PbList<SetCustomPasswordlessRegistrationMessageTextRequest>
no setter
passwordResetMessages → PbList<SetCustomPasswordResetMessageTextRequest>
no setter
privacyPolicy ↔ AddCustomPrivacyPolicyRequest
getter/setter pair
projectGrantMembers → PbList<AddProjectGrantMemberRequest>
no setter
projectGrants → PbList<DataProjectGrant>
no setter
projectMembers → PbList<AddProjectMemberRequest>
no setter
projectRoles → PbList<AddProjectRoleRequest>
no setter
projects → PbList<DataProject>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondFactors → PbList<AddSecondFactorToLoginPolicyRequest>
no setter
triggerActions → PbList<SetTriggerActionsRequest>
no setter
unknownFields → UnknownFieldSet
no setterinherited
userGrants → PbList<AddUserGrantRequest>
no setter
no setter
userMetadata → PbList<SetUserMetadataRequest>
no setter
verifyEmailMessages → PbList<SetCustomVerifyEmailMessageTextRequest>
no setter
verifyPhoneMessages → PbList<SetCustomVerifyPhoneMessageTextRequest>
no setter

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearIamPolicy() → void
clearLabelPolicy() → void
clearLockoutPolicy() → void
clearLoginPolicy() → void
clearOrg() → void
clearOrgId() → void
clearPasswordComplexityPolicy() → void
clearPrivacyPolicy() → void
clone() → DataOrg
Creates a deep copy of the fields in this message.
copyWith(void updates(DataOrg)) → DataOrg
Apply updates to a copy of this message.
createEmptyInstance() → DataOrg
Creates an empty instance of the same message type as this.
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
ensureIamPolicy() → AddCustomOrgIAMPolicyRequest
ensureLabelPolicy() → AddCustomLabelPolicyRequest
ensureLockoutPolicy() → AddCustomLockoutPolicyRequest
ensureLoginPolicy() → AddCustomLoginPolicyRequest
ensureOrg() → AddOrgRequest
ensurePasswordComplexityPolicy() → AddCustomPasswordComplexityPolicyRequest
ensurePrivacyPolicy() → AddCustomPrivacyPolicyRequest
extensionsAreInitialized() → bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) → int?
inherited
hasExtension(Extension extension) → bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) → bool
Whether this message has a field associated with tagNumber.
inherited
hasIamPolicy() → bool
hasLabelPolicy() → bool
hasLockoutPolicy() → bool
hasLoginPolicy() → bool
hasOrg() → bool
hasOrgId() → bool
hasPasswordComplexityPolicy() → bool
hasPrivacyPolicy() → bool
hasRequiredFields() → bool
Whether the message has required fields.
inherited
isInitialized() → bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() → String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() → String
Returns a String representation of this message.
inherited
writeToBuffer() → Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() → String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() → Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

create() → DataOrg
getDefault() → DataOrg