activateWebKey method

ResponseFuture<ActivateWebKeyResponse> activateWebKey(
  1. ActivateWebKeyRequest request, {
  2. CallOptions? options,
})

Activate Web Key

Switch the active signing web key. The previously active key will be deactivated. Note that the JWKs OIDC endpoint returns a cacheable response. Therefore it is not advised to activate a key that has been created within the cache duration (default is 5min), as the public key may not have been propagated to caches and clients yet.

Required permission:

  • iam.web_key.write

Implementation

$grpc.ResponseFuture<$0.ActivateWebKeyResponse> activateWebKey(
  $0.ActivateWebKeyRequest request, {
  $grpc.CallOptions? options,
}) {
  return $createUnaryCall(_$activateWebKey, request, options: options);
}