removePublicKey method
ResponseFuture<RemovePublicKeyResponse>
removePublicKey(
- RemovePublicKeyRequest request, {
- CallOptions? options,
Remove Public Key
Removes the public key from the target. This is a permanent action and can not be undone. Note that you can only remove inactive keys. Attempting to remove an active key will result in an error. For break glass scenarios, deactivate the key first and then remove it. Removing a non-existing key is a no-op.
Required permission:
action.target.write
Implementation
$grpc.ResponseFuture<$0.RemovePublicKeyResponse> removePublicKey(
$0.RemovePublicKeyRequest request, {
$grpc.CallOptions? options,
}) {
return $createUnaryCall(_$removePublicKey, request, options: options);
}