AuthRequest class
AuthRequest represents an OpenID Connect Authorization Request as defined in https://openid.net/specs/openid-connect-core-1_0.html#AuthRequest
- Available extensions
Constructors
-
AuthRequest({String? id, Timestamp? creationDate, String? clientId, Iterable<
String> ? scope, String? redirectUri, Iterable<Prompt> ? prompt, Iterable<String> ? uiLocales, String? loginHint, Duration? maxAge, String? hintUserId}) -
factory
-
AuthRequest.fromBuffer(List<
int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY]) -
factory
- AuthRequest.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
-
factory
Properties
- clientId ↔ String
-
The OAuth2/OIDC client_id of the application that initiated the authorization request.
getter/setter pair
- creationDate ↔ Timestamp
-
The timestamp when the authorization request was created.
getter/setter pair
- hashCode → int
-
Calculates a hash code based on the contents of the protobuf.
no setterinherited
- hintUserId ↔ String
-
User ID taken from a ID Token Hint if it was present and valid.
getter/setter pair
- id ↔ String
-
The unique identifier of the authorization request.
getter/setter pair
- info_ → BuilderInfo
-
no setter
- isFrozen → bool
-
Returns
trueif this message is marked read-only. Otherwisefalse.no setterinherited - loginHint ↔ String
-
Login hint can be set by the application with a user identifier such as an email or phone number.
getter/setter pair
- maxAge ↔ Duration
-
Specifies the allowable elapsed time in seconds since the last time the End-User was actively authenticated.
If the elapsed time is greater than this value, or the field is present with 0 duration, the user must be re-authenticated.
getter/setter pair
-
prompt
→ PbList<
Prompt> -
Prompts that must be displayed to the user.
no setter
- redirectUri ↔ String
-
The redirect_uri used in the authorization request. This must exactly match one of the redirect URIs registered for the client.
This uri is used to send the authorization code or tokens back to the application.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scope
→ PbList<
String> -
The scopes by the application that the user must consent to.
no setter
-
uiLocales
→ PbList<
String> -
End-User's preferred languages and scripts for the user interface, represented as a list of BCP47
RFC5646language tag values, ordered by preference. For instance, the valuefr-CA, fr, enrepresents a preference for French as spoken in Canada, then French (without a region designation), followed by English (without a region designation). An error SHOULD NOT result if some or all of the requested locales are not supported.no setter - unknownFields → UnknownFieldSet
-
no setterinherited
Methods
-
addExtension(
Extension extension, Object? value) → void -
Adds an extension field value to a repeated field.
inherited
-
check(
) → void -
Throws a StateError if the message has required fields without a value.
inherited
-
clear(
) → void -
Clears all data that was set in this message.
inherited
-
clearClientId(
) → void -
clearCreationDate(
) → void -
clearExtension(
Extension extension) → void -
Clears an extension field and also removes the extension.
inherited
-
clearField(
int tagNumber) → void -
Clears the contents of a given field.
inherited
-
clearHintUserId(
) → void -
clearId(
) → void -
clearLoginHint(
) → void -
clearMaxAge(
) → void -
clearRedirectUri(
) → void -
clone(
) → AuthRequest - Creates a deep copy of the fields in this message.
-
copyWith(
void updates(AuthRequest)) → AuthRequest -
Apply
updatesto a copy of this message. -
createEmptyInstance(
) → AuthRequest - Creates an empty instance of the same message type as this.
-
deepCopy(
) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Returns a writable deep copy of this message. -
ensureCreationDate(
) → Timestamp -
ensureMaxAge(
) → Duration -
extensionsAreInitialized(
) → bool -
inherited
-
freeze(
) → GeneratedMessage -
Make this message read-only.
inherited
-
getDefaultForField(
int tagNumber) → dynamic -
Returns the default value for the given field.
inherited
-
getExtension(
Extension extension) → dynamic -
Returns the value of
extension.inherited -
getField(
int tagNumber) → dynamic -
Returns the value of the field associated with
tagNumber, or the default value if it is not set.inherited -
getFieldOrNull(
int tagNumber) → dynamic -
Returns the value of a field, ignoring any defaults.
inherited
-
getTagNumber(
String fieldName) → int? -
inherited
-
hasClientId(
) → bool -
hasCreationDate(
) → bool -
hasExtension(
Extension extension) → bool -
Returns
trueif a value ofextensionis present.inherited -
hasField(
int tagNumber) → bool -
Whether this message has a field associated with
tagNumber.inherited -
hasHintUserId(
) → bool -
hasId(
) → bool -
hasLoginHint(
) → bool -
hasMaxAge(
) → bool -
hasRedirectUri(
) → bool -
hasRequiredFields(
) → bool -
Whether the message has required fields.
inherited
-
isInitialized(
) → bool -
Whether all required fields in the message and embedded messages are set.
inherited
-
mergeFromBuffer(
List< int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges serialized protocol buffer data into this message.
inherited
-
mergeFromCodedBufferReader(
CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Same as
mergeFromBuffer, but takes aCodedBufferReaderinput.inherited -
mergeFromJson(
String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from
data, a JSON object, encoded as described byGeneratedMessage.writeToJson.inherited -
mergeFromJsonMap(
Map< String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from a JSON object represented as a Dart map.
inherited
-
mergeFromMessage(
GeneratedMessage other) → void -
Merges the contents of the
otherinto this message.inherited -
mergeFromProto3Json(
Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void -
Merges field values from
json, a JSON object using proto3 encoding.inherited -
mergeUnknownFields(
UnknownFieldSet unknownFieldSet) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates(T)) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Applyupdatesto a copy of this message. -
setExtension(
Extension extension, Object value) → void -
Sets the value of a non-repeated extension field to
value.inherited -
setField(
int tagNumber, Object value) → void -
Sets the value of a field by its
tagNumber.inherited -
toBuilder(
) → GeneratedMessage -
Creates a writable, shallow copy of this message.
inherited
-
toDebugString(
) → String -
Returns a String representation of this message.
inherited
-
toProto3Json(
{TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object? -
Returns an Object representing Proto3 JSON serialization of
this.inherited -
toString(
) → String -
Returns a String representation of this message.
inherited
-
writeToBuffer(
) → Uint8List -
Serialize the message as the protobuf binary format.
inherited
-
writeToCodedBufferWriter(
CodedBufferWriter output) → void -
Same as
writeToBuffer, but serializes to the givenCodedBufferWriter.inherited -
writeToJson(
) → String -
Returns a JSON string that encodes this message.
inherited
-
writeToJsonMap(
) → Map< String, dynamic> -
Returns the JSON encoding of this message as a Dart Map.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
create(
) → AuthRequest -
getDefault(
) → AuthRequest