AuthorizationServiceClient class
Note: We have streamlined our naming conventions to improve clarity. Authorization in this context refers to role assignments, not to OAuth authorization.
AuthorizationService provides methods to manage authorizations for users within your projects and applications.
For managing permissions and roles for Zitadel internal resources, like organizations, projects, users, etc., please use the InternalPermissionService.
- Annotations
-
- @GrpcServiceName.new('zitadel.authorization.v2.AuthorizationService')
Constructors
-
AuthorizationServiceClient(ClientChannel channel, {CallOptions? options, Iterable<
ClientInterceptor> ? interceptors})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$createCall<
Q, R> (ClientMethod< Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R> -
inherited
-
$createStreamingCall<
Q, R> (ClientMethod< Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R> -
inherited
-
$createUnaryCall<
Q, R> (ClientMethod< Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R> -
inherited
-
activateAuthorization(
ActivateAuthorizationRequest request, {CallOptions? options}) → ResponseFuture< ActivateAuthorizationResponse> - Activate Role Assignment
-
createAuthorization(
CreateAuthorizationRequest request, {CallOptions? options}) → ResponseFuture< CreateAuthorizationResponse> - Create Role Assignment
-
deactivateAuthorization(
DeactivateAuthorizationRequest request, {CallOptions? options}) → ResponseFuture< DeactivateAuthorizationResponse> - Deactivate Role Assignment
-
deleteAuthorization(
DeleteAuthorizationRequest request, {CallOptions? options}) → ResponseFuture< DeleteAuthorizationResponse> - Delete Role Assignment
-
listAuthorizations(
ListAuthorizationsRequest request, {CallOptions? options}) → ResponseFuture< ListAuthorizationsResponse> - List Role Assignment
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateAuthorization(
UpdateAuthorizationRequest request, {CallOptions? options}) → ResponseFuture< UpdateAuthorizationResponse> - Update Role Assignments
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultHost → const String
- The hostname for this service.
-
oauthScopes
→ const List<
String> - OAuth scopes needed for the client.