createAuthorization method
ResponseFuture<CreateAuthorizationResponse>
createAuthorization(
- CreateAuthorizationRequest request, {
- CallOptions? options,
Create Role Assignment
Note: Authorization in this context refers to role assignments, not to OAuth authorization.
CreateAuthorization creates a new authorization for a user in an owned or granted project.
Required permissions:
- "user.grant.write"
Implementation
$grpc.ResponseFuture<$0.CreateAuthorizationResponse> createAuthorization(
$0.CreateAuthorizationRequest request, {
$grpc.CallOptions? options,
}) {
return $createUnaryCall(_$createAuthorization, request, options: options);
}