deactivateAuthorization method
ResponseFuture<DeactivateAuthorizationResponse>
deactivateAuthorization(
- DeactivateAuthorizationRequest request, {
- CallOptions? options,
Deactivate Role Assignment
DeactivateAuthorization deactivates an existing and active authorization.
Note: Authorization in this context refers to role assignments, not to OAuth authorization.
In case the authorization is already inactive, the request will return a successful response as the desired state is already achieved. You can check the change date in the response to verify if the authorization was deactivated by the request.
Required permissions:
- "user.grant.write"
Implementation
$grpc.ResponseFuture<$0.DeactivateAuthorizationResponse>
deactivateAuthorization(
$0.DeactivateAuthorizationRequest request, {
$grpc.CallOptions? options,
}) {
return $createUnaryCall(_$deactivateAuthorization, request,
options: options);
}