deleteAuthorization method

ResponseFuture<DeleteAuthorizationResponse> deleteAuthorization(
  1. DeleteAuthorizationRequest request, {
  2. CallOptions? options,
})

Delete Role Assignment

Note: Authorization in this context refers to role assignments, not to OAuth authorization.

DeleteAuthorization deletes the authorization.

In case the authorization is not found, the request will return a successful response as the desired state is already achieved. You can check the deletion date in the response to verify if the authorization was deleted by the request.

Required permissions:

  • "user.grant.delete"

Implementation

$grpc.ResponseFuture<$0.DeleteAuthorizationResponse> deleteAuthorization(
  $0.DeleteAuthorizationRequest request, {
  $grpc.CallOptions? options,
}) {
  return $createUnaryCall(_$deleteAuthorization, request, options: options);
}