webAuthN property
WebAuthN requests a challenge to be used in the WebAuthN authentication ceremony. They can be used for both passkey and U2F authentication. They're required for a webauthn check at the SetSession endpoint.
Implementation
@$pb.TagNumber(1)
RequestChallenges_WebAuthN get webAuthN => $_getN(0);
Implementation
@$pb.TagNumber(1)
set webAuthN(RequestChallenges_WebAuthN value) => $_setField(1, value);