STATE_REMOVED constant
State
const STATE_REMOVED
The removed key is not used to sign tokens anymore and not published to the public key endpoint.
Implementation
static const State STATE_REMOVED =
State._(4, _omitEnumNames ? '' : 'STATE_REMOVED');