maxPasswordAttempts property
- @TagNumber.new(1)
The amount of failed password attempts before the account gets locked. Attempts are reset as soon as the password is entered correctly or the password is reset. If set to 0 the account will never be locked.
Implementation
@$pb.TagNumber(1)
$fixnum.Int64 get maxPasswordAttempts => $_getI64(0);
- @TagNumber.new(1)
Implementation
@$pb.TagNumber(1)
set maxPasswordAttempts($fixnum.Int64 value) => $_setInt64(0, value);