LoginSettings class
- Available extensions
Constructors
-
LoginSettings({@Deprecated('This field is deprecated.') bool? allowUsernamePassword, bool? allowRegister, bool? allowExternalIdp, bool? forceMfa, PasskeysType? passkeysType, bool? hidePasswordReset, bool? ignoreUnknownUsernames, String? defaultRedirectUri, Duration? passwordCheckLifetime, Duration? externalLoginCheckLifetime, Duration? mfaInitSkipLifetime, Duration? secondFactorCheckLifetime, Duration? multiFactorCheckLifetime, Iterable<
SecondFactorType> ? secondFactors, Iterable<MultiFactorType> ? multiFactors, bool? allowDomainDiscovery, bool? disableLoginWithEmail, bool? disableLoginWithPhone, ResourceOwnerType? resourceOwnerType, bool? allowLocalAuthentication, bool? forceMfaLocalOnly}) -
factory
-
LoginSettings.fromBuffer(List<
int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY]) -
factory
- LoginSettings.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
-
factory
Properties
- allowDomainDiscovery ↔ bool
-
Allow discovery of the organization and its authentication option by domain.
If set to true, the suffix (@domain.com) of an unknown username input on the login screen
will be matched against the Organization Domains and will redirect to the registration of that organization on success.
The registration can either be locally (requires allow_register to be true) or through an external identity provider.
In case only one identity provider is configured for the organization, the user will be redirected directly to the identity provider.
getter/setter pair
- allowExternalIdp ↔ bool
-
If enabled, users will generally be allowed to use an external identity provider to log in.
Be sure to allow at least one external identity provider if this option is enabled.
getter/setter pair
- allowLocalAuthentication ↔ bool
-
If enabled, users can log in locally with their username and passkeys or password.
Disabling this option will require users to log in with an external identity provider.
Be sure to allow at least one external identity provider if this option is disabled.
getter/setter pair
- allowRegister ↔ bool
-
If enabled, users can register a local account by themself.
This option does not effect external identity providers.
Each identity provider can be configured to allow or disallow registration.
getter/setter pair
- allowUsernamePassword ↔ bool
-
If enabled, users can log in locally with their username and passkeys or password.
Disabling this option will require users to log in with an external identity provider.
Be sure to allow at least one external identity provider if this option is disabled.
Deprecated: check allow_local_authentication instead.
getter/setter pair
- defaultRedirectUri ↔ String
-
Defines where the user will be redirected to if the login is started without app context (e.g. from mail).
getter/setter pair
- disableLoginWithEmail ↔ bool
-
By default, users can login with their verified email address additionally to their login name.
Setting this to true disables the email login.
Note: If the email is set as the login name, this setting has no effect.
getter/setter pair
- disableLoginWithPhone ↔ bool
-
By default, users can login with their verified phone number additionally to their login name.
Setting this to true disables the phone number login.
Note: If the phone number is set as the login name, this setting has no effect.
getter/setter pair
- externalLoginCheckLifetime ↔ Duration
-
The duration a login through an external identity provider is valid.
After this time has passed, the user will be required to re-authenticate with the
external identity provider on the next action that requires authentication.
Note that this does not enforce a logout or session expiration.
getter/setter pair
- forceMfa ↔ bool
-
If enabled, users will be forced to use a multi-factor to log in.
This also applies to federated logins through an external identity provider.
Users will be required to set up a second factor if they have not done so already.
getter/setter pair
- forceMfaLocalOnly ↔ bool
-
If enabled, users will be forced to use a multi-factor to log in if they authenticated locally.
This does not apply to federated logins through an external identity provider.
Users will be required to set up a second factor if they have not done so already.
If both force_mfa and force_mfa_local_only are enabled, force_mfa takes precedence and
all logins will require a second factor.
getter/setter pair
- hashCode → int
-
Calculates a hash code based on the contents of the protobuf.
no setterinherited
- hidePasswordReset ↔ bool
-
If enabled, the password reset link will be hidden on the login screen.
getter/setter pair
- ignoreUnknownUsernames ↔ bool
-
If enabled, an unknown username on the login screen will not return an error directly,
but will always display the password screen.
This prevents user enumeration attacks.
getter/setter pair
- info_ → BuilderInfo
-
no setter
- isFrozen → bool
-
Returns
trueif this message is marked read-only. Otherwisefalse.no setterinherited - mfaInitSkipLifetime ↔ Duration
-
Defines after how much time the mfa prompt will be shown again.
getter/setter pair
- multiFactorCheckLifetime ↔ Duration
-
The duration a multi-factor check is valid.
After this time has passed, the user will be required to re-validate their
multi-factor on the next action that requires authentication.
Note that this does not enforce a logout or session expiration.
getter/setter pair
-
multiFactors
→ PbList<
MultiFactorType> -
The list of allowed multi factors.
no setter
- passkeysType ↔ PasskeysType
-
Defines the usage of passkeys for users.
PASSKEYS_TYPE_NOT_ALLOWED: Users are not allowed to use passkeys.
PASSKEYS_TYPE_ALLOWED: Users are allowed to use passkeys.
There will be additional options in the future.
If passkeys are allowed, users can choose to use passkeys or password for local authentication.
A verified passkey authentication will not require a second factor, if force_mfa is enabled.
getter/setter pair
- passwordCheckLifetime ↔ Duration
-
The duration a password check is valid.
After this time has passed, the user will be required to re-validate their
password on the next action that requires authentication.
Note that this does not enforce a logout or session expiration.
getter/setter pair
- resourceOwnerType ↔ ResourceOwnerType
-
ResourceOwnerType returns if the settings is managed on the organization explicitly or
fell back on the instance settings.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondFactorCheckLifetime ↔ Duration
-
The duration a second factor check is valid.
After this time has passed, the user will be required to re-validate their
second factor on the next action that requires authentication.
Note that this does not enforce a logout or session expiration.
getter/setter pair
-
secondFactors
→ PbList<
SecondFactorType> -
The list of allowed second factors.
no setter
- unknownFields → UnknownFieldSet
-
no setterinherited
Methods
-
addExtension(
Extension extension, Object? value) → void -
Adds an extension field value to a repeated field.
inherited
-
check(
) → void -
Throws a StateError if the message has required fields without a value.
inherited
-
clear(
) → void -
Clears all data that was set in this message.
inherited
-
clearAllowDomainDiscovery(
) → void -
clearAllowExternalIdp(
) → void -
clearAllowLocalAuthentication(
) → void -
clearAllowRegister(
) → void -
clearAllowUsernamePassword(
) → void -
clearDefaultRedirectUri(
) → void -
clearDisableLoginWithEmail(
) → void -
clearDisableLoginWithPhone(
) → void -
clearExtension(
Extension extension) → void -
Clears an extension field and also removes the extension.
inherited
-
clearExternalLoginCheckLifetime(
) → void -
clearField(
int tagNumber) → void -
Clears the contents of a given field.
inherited
-
clearForceMfa(
) → void -
clearForceMfaLocalOnly(
) → void -
clearHidePasswordReset(
) → void -
clearIgnoreUnknownUsernames(
) → void -
clearMfaInitSkipLifetime(
) → void -
clearMultiFactorCheckLifetime(
) → void -
clearPasskeysType(
) → void -
clearPasswordCheckLifetime(
) → void -
clearResourceOwnerType(
) → void -
clearSecondFactorCheckLifetime(
) → void -
clone(
) → LoginSettings - Creates a deep copy of the fields in this message.
-
copyWith(
void updates(LoginSettings)) → LoginSettings -
Apply
updatesto a copy of this message. -
createEmptyInstance(
) → LoginSettings - Creates an empty instance of the same message type as this.
-
deepCopy(
) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Returns a writable deep copy of this message. -
ensureExternalLoginCheckLifetime(
) → Duration -
ensureMfaInitSkipLifetime(
) → Duration -
ensureMultiFactorCheckLifetime(
) → Duration -
ensurePasswordCheckLifetime(
) → Duration -
ensureSecondFactorCheckLifetime(
) → Duration -
extensionsAreInitialized(
) → bool -
inherited
-
freeze(
) → GeneratedMessage -
Make this message read-only.
inherited
-
getDefaultForField(
int tagNumber) → dynamic -
Returns the default value for the given field.
inherited
-
getExtension(
Extension extension) → dynamic -
Returns the value of
extension.inherited -
getField(
int tagNumber) → dynamic -
Returns the value of the field associated with
tagNumber, or the default value if it is not set.inherited -
getFieldOrNull(
int tagNumber) → dynamic -
Returns the value of a field, ignoring any defaults.
inherited
-
getTagNumber(
String fieldName) → int? -
inherited
-
hasAllowDomainDiscovery(
) → bool -
hasAllowExternalIdp(
) → bool -
hasAllowLocalAuthentication(
) → bool -
hasAllowRegister(
) → bool -
hasAllowUsernamePassword(
) → bool -
hasDefaultRedirectUri(
) → bool -
hasDisableLoginWithEmail(
) → bool -
hasDisableLoginWithPhone(
) → bool -
hasExtension(
Extension extension) → bool -
Returns
trueif a value ofextensionis present.inherited -
hasExternalLoginCheckLifetime(
) → bool -
hasField(
int tagNumber) → bool -
Whether this message has a field associated with
tagNumber.inherited -
hasForceMfa(
) → bool -
hasForceMfaLocalOnly(
) → bool -
hasHidePasswordReset(
) → bool -
hasIgnoreUnknownUsernames(
) → bool -
hasMfaInitSkipLifetime(
) → bool -
hasMultiFactorCheckLifetime(
) → bool -
hasPasskeysType(
) → bool -
hasPasswordCheckLifetime(
) → bool -
hasRequiredFields(
) → bool -
Whether the message has required fields.
inherited
-
hasResourceOwnerType(
) → bool -
hasSecondFactorCheckLifetime(
) → bool -
isInitialized(
) → bool -
Whether all required fields in the message and embedded messages are set.
inherited
-
mergeFromBuffer(
List< int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges serialized protocol buffer data into this message.
inherited
-
mergeFromCodedBufferReader(
CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Same as
mergeFromBuffer, but takes aCodedBufferReaderinput.inherited -
mergeFromJson(
String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from
data, a JSON object, encoded as described byGeneratedMessage.writeToJson.inherited -
mergeFromJsonMap(
Map< String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from a JSON object represented as a Dart map.
inherited
-
mergeFromMessage(
GeneratedMessage other) → void -
Merges the contents of the
otherinto this message.inherited -
mergeFromProto3Json(
Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void -
Merges field values from
json, a JSON object using proto3 encoding.inherited -
mergeUnknownFields(
UnknownFieldSet unknownFieldSet) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates(T)) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Applyupdatesto a copy of this message. -
setExtension(
Extension extension, Object value) → void -
Sets the value of a non-repeated extension field to
value.inherited -
setField(
int tagNumber, Object value) → void -
Sets the value of a field by its
tagNumber.inherited -
toBuilder(
) → GeneratedMessage -
Creates a writable, shallow copy of this message.
inherited
-
toDebugString(
) → String -
Returns a String representation of this message.
inherited
-
toProto3Json(
{TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object? -
Returns an Object representing Proto3 JSON serialization of
this.inherited -
toString(
) → String -
Returns a String representation of this message.
inherited
-
writeToBuffer(
) → Uint8List -
Serialize the message as the protobuf binary format.
inherited
-
writeToCodedBufferWriter(
CodedBufferWriter output) → void -
Same as
writeToBuffer, but serializes to the givenCodedBufferWriter.inherited -
writeToJson(
) → String -
Returns a JSON string that encodes this message.
inherited
-
writeToJsonMap(
) → Map< String, dynamic> -
Returns the JSON encoding of this message as a Dart Map.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
create(
) → LoginSettings -
getDefault(
) → LoginSettings