secondFactorCheckLifetime property
The duration a second factor check is valid. After this time has passed, the user will be required to re-validate their second factor on the next action that requires authentication. Note that this does not enforce a logout or session expiration.
Implementation
@$pb.TagNumber(12)
$0.Duration get secondFactorCheckLifetime => $_getN(11);
Implementation
@$pb.TagNumber(12)
set secondFactorCheckLifetime($0.Duration value) => $_setField(12, value);