token property
Token is a verification token that needs to be added to the DNS records or as a file to the webserver. Zitadel will check for this token to verify the domain.
Implementation
@$pb.TagNumber(1)
$core.String get token => $_getSZ(0);
Implementation
@$pb.TagNumber(1)
set token($core.String value) => $_setString(0, value);