deleteOrganizationDomain method
ResponseFuture<DeleteOrganizationDomainResponse>
deleteOrganizationDomain(
- DeleteOrganizationDomainRequest request, {
- CallOptions? options,
Delete Organization Domain
Deprecated: please move to the corresponding endpoint under organization service v2. This endpoint will be removed with the next major version of ZITADEL.
Delete a new domain from an organization. The domains are used to identify to which organization a user belongs. If the uses use the domain for login, this will not be possible afterwards. They have to use another domain instead.
Required permission:
org.write
Implementation
$grpc.ResponseFuture<$0.DeleteOrganizationDomainResponse>
deleteOrganizationDomain(
$0.DeleteOrganizationDomainRequest request, {
$grpc.CallOptions? options,
}) {
return $createUnaryCall(_$deleteOrganizationDomain, request,
options: options);
}