setOrganizationMetadata method

ResponseFuture<SetOrganizationMetadataResponse> setOrganizationMetadata(
  1. SetOrganizationMetadataRequest request, {
  2. CallOptions? options,
})

Set Organization Metadata

Sets a list of key value pairs. Existing metadata entries with matching keys are overwritten. Existing metadata entries without matching keys are untouched. To remove existing metadata entries, pass an empty metadata value or use DeleteOrganizationMetadata. If no metadata entry exists for a given key, passing an empty value for that key has no effect (no-op). For HTTP requests, make sure the bytes array value is base64 encoded.

Required permission:

  • org.write

Implementation

$grpc.ResponseFuture<$0.SetOrganizationMetadataResponse>
    setOrganizationMetadata(
  $0.SetOrganizationMetadataRequest request, {
  $grpc.CallOptions? options,
}) {
  return $createUnaryCall(_$setOrganizationMetadata, request,
      options: options);
}