roleKey property
RoleKey identifies the role. It's the only relevant attribute for ZITADEL and will be used for authorization checks and as claim in tokens and user info responses.
Implementation
@$pb.TagNumber(2)
$core.String get roleKey => $_getSZ(1);
Implementation
@$pb.TagNumber(2)
set roleKey($core.String value) => $_setString(1, value);