authorizationRequired property
AuthorizationRequired is a boolean flag that can be enabled to check if a user has an authorization to use this project assigned when login into an application of this project.
Implementation
@$pb.TagNumber(5)
$core.bool get authorizationRequired => $_getBF(4);
Implementation
@$pb.TagNumber(5)
set authorizationRequired($core.bool value) => $_setBool(4, value);