updateProjectGrant method
ResponseFuture<UpdateProjectGrantResponse>
updateProjectGrant(
- UpdateProjectGrantRequest request, {
- CallOptions? options,
Update Project Grant
Change the roles of the project that is granted to another organization. The project grant will allow the granted organization to access the project and manage the authorizations for its users.
Required permission:
project.grant.write
Implementation
$grpc.ResponseFuture<$0.UpdateProjectGrantResponse> updateProjectGrant(
$0.UpdateProjectGrantRequest request, {
$grpc.CallOptions? options,
}) {
return $createUnaryCall(_$updateProjectGrant, request, options: options);
}