authorizationRequired property
AuthorizationRequired is a boolean flag that can be enabled to check if a user has a role of this project assigned when logging into an application of this project. If omitted, the setting will remain unchanged.
Implementation
@$pb.TagNumber(4)
$core.bool get authorizationRequired => $_getBF(3);
Implementation
@$pb.TagNumber(4)
set authorizationRequired($core.bool value) => $_setBool(3, value);