changeDate property
ChangeDate is the timestamp when the administrator role was last updated. In case the administrator role was not updated, this field is equal to the creation date.
Implementation
@$pb.TagNumber(2)
$0.Timestamp get changeDate => $_getN(1);
Implementation
@$pb.TagNumber(2)
set changeDate($0.Timestamp value) => $_setField(2, value);