authorizationRequired property
When enabled, ZITADEL will check if a user has appropriate role assignments to use this project when they log into an application of this project.
Implementation
@$pb.TagNumber(8)
$core.bool get authorizationRequired => $_getBF(7);
Implementation
@$pb.TagNumber(8)
set authorizationRequired($core.bool value) => $_setBool(7, value);