grantedState property
GrantedProjectState describes the current state of the granted project. In case the project is not granted, this field is set to GrantedProjectState.GRANTED_PROJECT_STATE_UNSPECIFIED.
Implementation
@$pb.TagNumber(14)
GrantedProjectState get grantedState => $_getN(12);
Implementation
@$pb.TagNumber(14)
set grantedState(GrantedProjectState value) => $_setField(14, value);