organizationIdFilter property
Filter for projects that are owned by or granted to a specific organization. You can specify whether to search for owned, granted or both types of projects.
Implementation
@$pb.TagNumber(3)
ProjectOrganizationIDFilter get organizationIdFilter => $_getN(2);
Implementation
@$pb.TagNumber(3)
set organizationIdFilter(ProjectOrganizationIDFilter value) =>
$_setField(3, value);