expirationDate property
ExpirationDate is the time the session will be automatically invalidated. If not set, the session does not expire automatically.
Implementation
@$pb.TagNumber(8)
$0.Timestamp get expirationDate => $_getN(7);
Implementation
@$pb.TagNumber(8)
set expirationDate($0.Timestamp value) => $_setField(8, value);