SetSessionRequest class
- Available extensions
Constructors
-
SetSessionRequest({String? sessionId, @Deprecated('This field is deprecated.') String? sessionToken, Checks? checks, Iterable<
MapEntry< ? metadata, RequestChallenges? challenges, Duration? lifetime})String, List< >int> > -
factory
-
SetSessionRequest.fromBuffer(List<
int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY]) -
factory
- SetSessionRequest.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
-
factory
Properties
- challenges ↔ RequestChallenges
-
Additional challenges to be requested for further verification.
The challenges will be created and returned in the response.
The challenges can then be used for further checks with the following SetSession method.
Requesting a challenge that was already requested will overwrite the previous challenge.
getter/setter pair
- checks ↔ Checks
-
Additional checks to be performed on the session.
Successful checks will be stated as factors on the session.
Re-executing a check that was already successful will overwrite the previous check time.
For example, if a password check was already successful, it can be re-checked to update the check time.
Note that a user check can only be performed once per session and cannot be changed afterwards.
Some checks require that the user is already checked, either in the previous or the same request.
For example, a password check requires that the user is already checked.
Other checks, like WebAuthN or IDP intent, require that the user is already checked and a challenge
was requested in any previous request.
On successful checks, the session's
factorsfield will be updated.getter/setter pair - hashCode → int
-
Calculates a hash code based on the contents of the protobuf.
no setterinherited
- info_ → BuilderInfo
-
no setter
- isFrozen → bool
-
Returns
trueif this message is marked read-only. Otherwisefalse.no setterinherited - lifetime ↔ Duration
-
Update the duration after which the session will be automatically invalidated.
If not set, the lifetime will not be changed.
Note that an expired session cannot be used for authentication anymore, but will still be listed
until it is deleted.
getter/setter pair
-
metadata
→ PbMap<
String, List< int> > -
Additional custom key value pairs to be stored on the session.
Existing keys will be overwritten. To delete a key, set its value to an empty byte array.
Note that metadata keys cannot be changed once the session has been created.
You need to create a new entry and delete the old one instead.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId ↔ String
-
The unique identifier of the session to be updated.
getter/setter pair
- sessionToken ↔ String
-
Deprecated: the session token is no longer required when updating a session
and will be ignored when provided.
getter/setter pair
- unknownFields → UnknownFieldSet
-
no setterinherited
Methods
-
addExtension(
Extension extension, Object? value) → void -
Adds an extension field value to a repeated field.
inherited
-
check(
) → void -
Throws a StateError if the message has required fields without a value.
inherited
-
clear(
) → void -
Clears all data that was set in this message.
inherited
-
clearChallenges(
) → void -
clearChecks(
) → void -
clearExtension(
Extension extension) → void -
Clears an extension field and also removes the extension.
inherited
-
clearField(
int tagNumber) → void -
Clears the contents of a given field.
inherited
-
clearLifetime(
) → void -
clearSessionId(
) → void -
clearSessionToken(
) → void -
clone(
) → SetSessionRequest - Creates a deep copy of the fields in this message.
-
copyWith(
void updates(SetSessionRequest)) → SetSessionRequest -
Apply
updatesto a copy of this message. -
createEmptyInstance(
) → SetSessionRequest - Creates an empty instance of the same message type as this.
-
deepCopy(
) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Returns a writable deep copy of this message. -
ensureChallenges(
) → RequestChallenges -
ensureChecks(
) → Checks -
ensureLifetime(
) → Duration -
extensionsAreInitialized(
) → bool -
inherited
-
freeze(
) → GeneratedMessage -
Make this message read-only.
inherited
-
getDefaultForField(
int tagNumber) → dynamic -
Returns the default value for the given field.
inherited
-
getExtension(
Extension extension) → dynamic -
Returns the value of
extension.inherited -
getField(
int tagNumber) → dynamic -
Returns the value of the field associated with
tagNumber, or the default value if it is not set.inherited -
getFieldOrNull(
int tagNumber) → dynamic -
Returns the value of a field, ignoring any defaults.
inherited
-
getTagNumber(
String fieldName) → int? -
inherited
-
hasChallenges(
) → bool -
hasChecks(
) → bool -
hasExtension(
Extension extension) → bool -
Returns
trueif a value ofextensionis present.inherited -
hasField(
int tagNumber) → bool -
Whether this message has a field associated with
tagNumber.inherited -
hasLifetime(
) → bool -
hasRequiredFields(
) → bool -
Whether the message has required fields.
inherited
-
hasSessionId(
) → bool -
hasSessionToken(
) → bool -
isInitialized(
) → bool -
Whether all required fields in the message and embedded messages are set.
inherited
-
mergeFromBuffer(
List< int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges serialized protocol buffer data into this message.
inherited
-
mergeFromCodedBufferReader(
CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Same as
mergeFromBuffer, but takes aCodedBufferReaderinput.inherited -
mergeFromJson(
String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from
data, a JSON object, encoded as described byGeneratedMessage.writeToJson.inherited -
mergeFromJsonMap(
Map< String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from a JSON object represented as a Dart map.
inherited
-
mergeFromMessage(
GeneratedMessage other) → void -
Merges the contents of the
otherinto this message.inherited -
mergeFromProto3Json(
Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void -
Merges field values from
json, a JSON object using proto3 encoding.inherited -
mergeUnknownFields(
UnknownFieldSet unknownFieldSet) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates(T)) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Applyupdatesto a copy of this message. -
setExtension(
Extension extension, Object value) → void -
Sets the value of a non-repeated extension field to
value.inherited -
setField(
int tagNumber, Object value) → void -
Sets the value of a field by its
tagNumber.inherited -
toBuilder(
) → GeneratedMessage -
Creates a writable, shallow copy of this message.
inherited
-
toDebugString(
) → String -
Returns a String representation of this message.
inherited
-
toProto3Json(
{TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object? -
Returns an Object representing Proto3 JSON serialization of
this.inherited -
toString(
) → String -
Returns a String representation of this message.
inherited
-
writeToBuffer(
) → Uint8List -
Serialize the message as the protobuf binary format.
inherited
-
writeToCodedBufferWriter(
CodedBufferWriter output) → void -
Same as
writeToBuffer, but serializes to the givenCodedBufferWriter.inherited -
writeToJson(
) → String -
Returns a JSON string that encodes this message.
inherited
-
writeToJsonMap(
) → Map< String, dynamic> -
Returns the JSON encoding of this message as a Dart Map.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited