api/zitadel/settings library
Reexport of generated resources for the gRPC settings library.
Classes
- DebugNotificationProvider
- EmailProvider
- EmailProviderHTTP
- EmailProviderSMTP
- EmailProviderState
- HTTPConfig
- OIDCSettings
- SecretGenerator
- SecretGeneratorQuery
- SecretGeneratorType
- SecretGeneratorTypeQuery
- SecurityPolicy
- SMSProvider
- SMSProviderConfigState
- SMTPConfig
- SMTPConfigState
- SMTPNoAuth
- SMTPNoAuth can be used when no authentication is required for the SMTP connection.
- SMTPPlainAuth
- SMTPPlainAuth adds plain authentication to the smtp connection. The username of the parent configuration is used in combination with the password in this message.
- SMTPXOAuth2Auth
- SMTPXOAuth2Auth adds XOAut2 authentication to the smtp connection. The username of the parent configuration is used in combination with the other parameters of this message.
- SMTPXOAuth2Auth_ClientCredentials
- ClientCredentials authenticates the SMTP client using Oauth 2.0 Client Credentials grant. https://datatracker.ietf.org/doc/html/rfc6749#section-4.4
- TwilioConfig
Enums
Extensions
- GeneratedMessageGenericExtensions on T
-
Extensions on
GeneratedMessages.
Constants
-
DebugNotificationProvider$json
→ const Map<
String, Object> -
EmailProvider$json
→ const Map<
String, Object> -
EmailProviderHTTP$json
→ const Map<
String, Object> -
EmailProviderSMTP$json
→ const Map<
String, Object> -
EmailProviderState$json
→ const Map<
String, Object> -
HTTPConfig$json
→ const Map<
String, Object> -
OIDCSettings$json
→ const Map<
String, Object> -
SecretGenerator$json
→ const Map<
String, Object> -
SecretGeneratorQuery$json
→ const Map<
String, Object> -
SecretGeneratorType$json
→ const Map<
String, Object> -
SecretGeneratorTypeQuery$json
→ const Map<
String, Object> -
SecurityPolicy$json
→ const Map<
String, Object> -
SMSProvider$json
→ const Map<
String, Object> -
SMSProviderConfigState$json
→ const Map<
String, Object> -
SMTPConfig$json
→ const Map<
String, Object> -
SMTPConfigState$json
→ const Map<
String, Object> -
SMTPNoAuth$json
→ const Map<
String, String> -
SMTPPlainAuth$json
→ const Map<
String, String> -
SMTPXOAuth2Auth$json
→ const Map<
String, Object> -
SMTPXOAuth2Auth_ClientCredentials$json
→ const Map<
String, Object> -
TwilioConfig$json
→ const Map<
String, Object>
Properties
- debugNotificationProviderDescriptor → Uint8List
-
Descriptor for
DebugNotificationProvider. Decode as agoogle.protobuf.DescriptorProto.final - emailProviderDescriptor → Uint8List
-
Descriptor for
EmailProvider. Decode as agoogle.protobuf.DescriptorProto.final - emailProviderHTTPDescriptor → Uint8List
-
Descriptor for
EmailProviderHTTP. Decode as agoogle.protobuf.DescriptorProto.final - emailProviderSMTPDescriptor → Uint8List
-
Descriptor for
EmailProviderSMTP. Decode as agoogle.protobuf.DescriptorProto.final - emailProviderStateDescriptor → Uint8List
-
Descriptor for
EmailProviderState. Decode as agoogle.protobuf.EnumDescriptorProto.final - hTTPConfigDescriptor → Uint8List
-
Descriptor for
HTTPConfig. Decode as agoogle.protobuf.DescriptorProto.final - oIDCSettingsDescriptor → Uint8List
-
Descriptor for
OIDCSettings. Decode as agoogle.protobuf.DescriptorProto.final - secretGeneratorDescriptor → Uint8List
-
Descriptor for
SecretGenerator. Decode as agoogle.protobuf.DescriptorProto.final - secretGeneratorQueryDescriptor → Uint8List
-
Descriptor for
SecretGeneratorQuery. Decode as agoogle.protobuf.DescriptorProto.final - secretGeneratorTypeDescriptor → Uint8List
-
Descriptor for
SecretGeneratorType. Decode as agoogle.protobuf.EnumDescriptorProto.final - secretGeneratorTypeQueryDescriptor → Uint8List
-
Descriptor for
SecretGeneratorTypeQuery. Decode as agoogle.protobuf.DescriptorProto.final - securityPolicyDescriptor → Uint8List
-
Descriptor for
SecurityPolicy. Decode as agoogle.protobuf.DescriptorProto.final - sMSProviderConfigStateDescriptor → Uint8List
-
Descriptor for
SMSProviderConfigState. Decode as agoogle.protobuf.EnumDescriptorProto.final - sMSProviderDescriptor → Uint8List
-
Descriptor for
SMSProvider. Decode as agoogle.protobuf.DescriptorProto.final - sMTPConfigDescriptor → Uint8List
-
Descriptor for
SMTPConfig. Decode as agoogle.protobuf.DescriptorProto.final - sMTPConfigStateDescriptor → Uint8List
-
Descriptor for
SMTPConfigState. Decode as agoogle.protobuf.EnumDescriptorProto.final - sMTPNoAuthDescriptor → Uint8List
-
Descriptor for
SMTPNoAuth. Decode as agoogle.protobuf.DescriptorProto.final - sMTPPlainAuthDescriptor → Uint8List
-
Descriptor for
SMTPPlainAuth. Decode as agoogle.protobuf.DescriptorProto.final - sMTPXOAuth2AuthDescriptor → Uint8List
-
Descriptor for
SMTPXOAuth2Auth. Decode as agoogle.protobuf.DescriptorProto.final - twilioConfigDescriptor → Uint8List
-
Descriptor for
TwilioConfig. Decode as agoogle.protobuf.DescriptorProto.final