defaultOrgId property
The unique identifier of the default organization. The default organization is used to assign new users to an organization if no other organization is specified. Deprecated: use default_organization_id instead.
Implementation
@$pb.TagNumber(1)
$core.String get defaultOrgId => $_getSZ(0);
Implementation
@$pb.TagNumber(1)
set defaultOrgId($core.String value) => $_setString(0, value);