getLockoutSettings method
ResponseFuture<GetLockoutSettingsResponse>
getLockoutSettings(
- GetLockoutSettingsRequest request, {
- CallOptions? options,
Get Lockout Settings
Get the lockout settings for the requested context. This can be the instance or an organization. In case of an organization, the returned settings will fall back to the instance settings if not explicitly set on the organization.
Lockout settings define how many failed attempts are allowed before a user is locked out.
Required permissions:
policy.read
Implementation
$grpc.ResponseFuture<$0.GetLockoutSettingsResponse> getLockoutSettings(
$0.GetLockoutSettingsRequest request, {
$grpc.CallOptions? options,
}) {
return $createUnaryCall(_$getLockoutSettings, request, options: options);
}