expirationDate property
ExpirationDate is the timestamp when the public key automatically expires and no longer will be used for payload encryption, even when active. Be sure to upload and activate a new public key before the expiration date to avoid failed executions.
Implementation
@$pb.TagNumber(5)
$0.Timestamp get expirationDate => $_getN(4);
Implementation
@$pb.TagNumber(5)
set expirationDate($0.Timestamp value) => $_setField(5, value);