username property
Set a new username that is unique within the instance. Beware that active tokens and sessions are invalidated when the username is changed.
Implementation
@$pb.TagNumber(2)
$core.String get username => $_getSZ(1);
Implementation
@$pb.TagNumber(2)
set username($core.String value) => $_setString(1, value);