phone property
Change the users phone number and/or trigger a verification SMS To delete the users phone number, leave the phone field empty and omit the verification field.
Implementation
@$pb.TagNumber(3)
$5.SetHumanPhone get phone => $_getN(2);
Implementation
@$pb.TagNumber(3)
set phone($5.SetHumanPhone value) => $_setField(3, value);