addKey method
Add a Key
Add a keys that can be used to securely authenticate at the Zitadel APIs using JWT profile authentication using short-lived tokens. Make sure you store the returned key safely, as you won't be able to read it from the Zitadel API anymore. Only users of type machine can have keys.
Required permission:
- user.write
Implementation
$grpc.ResponseFuture<$0.AddKeyResponse> addKey(
$0.AddKeyRequest request, {
$grpc.CallOptions? options,
}) {
return $createUnaryCall(_$addKey, request, options: options);
}