addOTPSMS method

ResponseFuture<AddOTPSMSResponse> addOTPSMS(
  1. AddOTPSMSRequest request, {
  2. CallOptions? options,
})

Add OTP SMS for a user

Add a new OTP SMS factor to the authenticated user. OTP SMS will enable the user to verify an OTP with the latest verified phone number. The phone number has to be verified to add the second factor..

Implementation

$grpc.ResponseFuture<$0.AddOTPSMSResponse> addOTPSMS(
  $0.AddOTPSMSRequest request, {
  $grpc.CallOptions? options,
}) {
  return $createUnaryCall(_$addOTPSMS, request, options: options);
}