listKeys method
Search Keys
List all matching keys. By default all keys of the instance on which the caller has permission to read the owning users are returned. Make sure to include a limit and sorting for pagination.
Required permission:
- user.read
Implementation
$grpc.ResponseFuture<$0.ListKeysResponse> listKeys(
$0.ListKeysRequest request, {
$grpc.CallOptions? options,
}) {
return $createUnaryCall(_$listKeys, request, options: options);
}