resendInviteCode method
ResponseFuture<ResendInviteCodeResponse>
resendInviteCode(
- ResendInviteCodeRequest request, {
- CallOptions? options,
Resend an invite code for a user
Deprecated: Use CreateInviteCode instead.
Resend an invite code for a user to initialize their first authentication method (password, passkeys, IdP) depending on the organization's available methods. A resend is only possible if a code has been created previously and sent to the user. If there is no code or it was directly returned, an error will be returned.
Implementation
$grpc.ResponseFuture<$0.ResendInviteCodeResponse> resendInviteCode(
$0.ResendInviteCodeRequest request, {
$grpc.CallOptions? options,
}) {
return $createUnaryCall(_$resendInviteCode, request, options: options);
}