unlockUser method
ResponseFuture<UnlockUserResponse>
unlockUser(
- UnlockUserRequest request, {
- CallOptions? options,
Unlock user
The state of the user will be changed to 'active'. The user will be able to log in again. The endpoint returns an error if the user is not in the state 'locked'.
Implementation
$grpc.ResponseFuture<$0.UnlockUserResponse> unlockUser(
$0.UnlockUserRequest request, {
$grpc.CallOptions? options,
}) {
return $createUnaryCall(_$unlockUser, request, options: options);
}