verifyInviteCode method
ResponseFuture<VerifyInviteCodeResponse>
verifyInviteCode(
- VerifyInviteCodeRequest request, {
- CallOptions? options,
Verify an invite code for a user
Verify the invite code of a user previously issued. This will set their email to a verified state and allow the user to set up their first authentication method (password, passkeys, IdP) depending on the organization's available methods.
Implementation
$grpc.ResponseFuture<$0.VerifyInviteCodeResponse> verifyInviteCode(
$0.VerifyInviteCodeRequest request, {
$grpc.CallOptions? options,
}) {
return $createUnaryCall(_$verifyInviteCode, request, options: options);
}